Class: Aws::CloudWatch::CompositeAlarm

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/composite_alarm.rbs,
lib/aws-sdk-cloudwatch/composite_alarm.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ CompositeAlarm #initialize(options = {}) ⇒ CompositeAlarm

Returns a new instance of CompositeAlarm.

Overloads:

  • #initialize(name, options = {}) ⇒ CompositeAlarm

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ CompositeAlarm

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/composite_alarm.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#actions_enabledBoolean

Indicates whether actions should be executed during any changes to the alarm state.

Returns:

  • (Boolean)


22
# File 'sig/composite_alarm.rbs', line 22

def actions_enabled: () -> bool

#actions_suppressed_byString

When the value is ALARM, it means that the actions are suppressed because the suppressor alarm is in ALARM When the value is WaitPeriod, it means that the actions are suppressed because the composite alarm is waiting for the suppressor alarm to go into into the ALARM state. The maximum waiting time is as specified in ActionsSuppressorWaitPeriod. After this time, the composite alarm performs its actions. When the value is ExtensionPeriod, it means that the actions are suppressed because the composite alarm is waiting after the suppressor alarm went out of the ALARM state. The maximum waiting time is as specified in ActionsSuppressorExtensionPeriod. After this time, the composite alarm performs its actions.

Returns:

  • (String)


61
# File 'sig/composite_alarm.rbs', line 61

def actions_suppressed_by: () -> ("WaitPeriod" | "ExtensionPeriod" | "Alarm")

#actions_suppressed_reasonString

Captures the reason for action suppression.

Returns:

  • (String)


64
# File 'sig/composite_alarm.rbs', line 64

def actions_suppressed_reason: () -> ::String

#actions_suppressorString

Actions will be suppressed if the suppressor alarm is in the ALARM state. ActionsSuppressor can be an AlarmName or an Amazon Resource Name (ARN) from an existing alarm.

Returns:

  • (String)


67
# File 'sig/composite_alarm.rbs', line 67

def actions_suppressor: () -> ::String

#actions_suppressor_extension_periodInteger

The maximum time in seconds that the composite alarm waits after suppressor alarm goes out of the ALARM state. After this time, the composite alarm performs its actions.

ExtensionPeriod is required only when ActionsSuppressor is specified.

Returns:

  • (Integer)


73
# File 'sig/composite_alarm.rbs', line 73

def actions_suppressor_extension_period: () -> ::Integer

#actions_suppressor_wait_periodInteger

The maximum time in seconds that the composite alarm waits for the suppressor alarm to go into the ALARM state. After this time, the composite alarm performs its actions.

WaitPeriod is required only when ActionsSuppressor is specified.

Returns:

  • (Integer)


70
# File 'sig/composite_alarm.rbs', line 70

def actions_suppressor_wait_period: () -> ::Integer

#alarm_actionsArray<String>

The actions to execute when this alarm transitions to the ALARM state from any other state. Each action is specified as an Amazon Resource Name (ARN).

Returns:

  • (Array<String>)


25
# File 'sig/composite_alarm.rbs', line 25

def alarm_actions: () -> ::Array[::String]

#alarm_arnString

The Amazon Resource Name (ARN) of the alarm.

Returns:

  • (String)


28
# File 'sig/composite_alarm.rbs', line 28

def alarm_arn: () -> ::String

#alarm_configuration_updated_timestampTime

The time stamp of the last update to the alarm configuration.

Returns:

  • (Time)


31
# File 'sig/composite_alarm.rbs', line 31

def alarm_configuration_updated_timestamp: () -> ::Time

#alarm_descriptionString

The description of the alarm.

Returns:

  • (String)


34
# File 'sig/composite_alarm.rbs', line 34

def alarm_description: () -> ::String

#alarm_ruleString

The rule that this alarm uses to evaluate its alarm state.

Returns:

  • (String)


37
# File 'sig/composite_alarm.rbs', line 37

def alarm_rule: () -> ::String

#clientClient

Returns:



178
# File 'lib/aws-sdk-cloudwatch/composite_alarm.rb', line 178

def client: () -> Client

#dataTypes::CompositeAlarm



82
# File 'sig/composite_alarm.rbs', line 82

def data: () -> Types::CompositeAlarm

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



85
# File 'sig/composite_alarm.rbs', line 85

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


composite_alarm.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


96
# File 'sig/composite_alarm.rbs', line 96

def delete: (

#describe_history(options = {}) ⇒ Types::DescribeAlarmHistoryOutput

Examples:

Request syntax with placeholder values


composite_alarm.describe_history({
  alarm_contributor_id: "ContributorId",
  alarm_types: ["CompositeAlarm"], # accepts CompositeAlarm, MetricAlarm, LogAlarm
  history_item_type: "ConfigurationUpdate", # accepts ConfigurationUpdate, StateUpdate, Action, AlarmContributorStateUpdate, AlarmContributorAction
  start_date: Time.now,
  end_date: Time.now,
  max_records: 1,
  next_token: "NextToken",
  scan_by: "TimestampDescending", # accepts TimestampDescending, TimestampAscending
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :alarm_contributor_id (String)

    The unique identifier of a specific alarm contributor to filter the alarm history results.

  • :alarm_types (Array<String>)

    Use this parameter to specify whether you want the operation to return metric alarms, composite alarms, or log alarms. If you omit this parameter, only metric alarms are returned.

  • :history_item_type (String)

    The type of alarm histories to retrieve.

  • :start_date (Time, DateTime, Date, Integer, String)

    The starting date to retrieve alarm history.

  • :end_date (Time, DateTime, Date, Integer, String)

    The ending date to retrieve alarm history.

  • :max_records (Integer)

    The maximum number of alarm history records to retrieve.

  • :next_token (String)

    The token returned by a previous call to indicate that there is more data available.

  • :scan_by (String)

    Specified whether to return the newest or oldest alarm history first. Specify TimestampDescending to have the newest event history returned first, and specify TimestampAscending to have the oldest history returned first.

Returns:



101
# File 'sig/composite_alarm.rbs', line 101

def describe_history: (

#disable_actions(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


composite_alarm.disable_actions()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


114
# File 'sig/composite_alarm.rbs', line 114

def disable_actions: (

#enable_actions(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


composite_alarm.enable_actions()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


119
# File 'sig/composite_alarm.rbs', line 119

def enable_actions: (

#exists?(options = {}) ⇒ Boolean

Returns true if the CompositeAlarm exists.

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (Boolean)

    Returns true if the CompositeAlarm exists.



88
89
# File 'sig/composite_alarm.rbs', line 88

def exists?: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) -> bool
| (?Hash[Symbol, untyped]) -> bool

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


462
463
464
# File 'lib/aws-sdk-cloudwatch/composite_alarm.rb', line 462

def identifiers
  { name: @name }
end

#insufficient_data_actionsArray<String>

The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).

Returns:

  • (Array<String>)


40
# File 'sig/composite_alarm.rbs', line 40

def insufficient_data_actions: () -> ::Array[::String]

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::CloudWatch::CompositeAlarm. Returns self making it possible to chain methods.

composite_alarm.reload.data

Returns:

  • (self)


78
# File 'sig/composite_alarm.rbs', line 78

def load: () -> self

#nameString Also known as: alarm_name

Returns:

  • (String)


18
# File 'sig/composite_alarm.rbs', line 18

def name: () -> String

#ok_actionsArray<String>

The actions to execute when this alarm transitions to the OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).

Returns:

  • (Array<String>)


43
# File 'sig/composite_alarm.rbs', line 43

def ok_actions: () -> ::Array[::String]

#set_state(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


composite_alarm.set_state({
  state_value: "OK", # required, accepts OK, ALARM, INSUFFICIENT_DATA
  state_reason: "StateReason", # required
  state_reason_data: "StateReasonData",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :state_value (required, String)

    The value of the state.

  • :state_reason (required, String)

    The reason that this alarm is set to this specific state, in text format.

  • :state_reason_data (String)

    The reason that this alarm is set to this specific state, in JSON format.

    For SNS or EC2 alarm actions, this is just informational. But for EC2 Auto Scaling or application Auto Scaling alarm actions, the Auto Scaling policy uses the information in this field to take the correct action.

Returns:

  • (EmptyStructure)


124
# File 'sig/composite_alarm.rbs', line 124

def set_state: (

#state_reasonString

An explanation for the alarm state, in text format.

Returns:

  • (String)


46
# File 'sig/composite_alarm.rbs', line 46

def state_reason: () -> ::String

#state_reason_dataString

An explanation for the alarm state, in JSON format.

Returns:

  • (String)


49
# File 'sig/composite_alarm.rbs', line 49

def state_reason_data: () -> ::String

#state_transitioned_timestampTime

The timestamp of the last change to the alarm's StateValue.

Returns:

  • (Time)


58
# File 'sig/composite_alarm.rbs', line 58

def state_transitioned_timestamp: () -> ::Time

#state_updated_timestampTime

Tracks the timestamp of any state update, even if StateValue doesn't change.

Returns:

  • (Time)


52
# File 'sig/composite_alarm.rbs', line 52

def state_updated_timestamp: () -> ::Time

#state_valueString

The state value for the alarm.

Returns:

  • (String)


55
# File 'sig/composite_alarm.rbs', line 55

def state_value: () -> ("OK" | "ALARM" | "INSUFFICIENT_DATA")

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::CloudWatch::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/aws-sdk-cloudwatch/composite_alarm.rb', line 325

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end

#wait_until_exists(options = {}, &block) ⇒ CompositeAlarm

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :max_attempts (Integer) — default: 40
  • :delay (Float) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)

Returns:



92
93
# File 'sig/composite_alarm.rbs', line 92

def wait_until_exists: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) ?{ (untyped waiter) -> void } -> CompositeAlarm
| (?Hash[Symbol, untyped]) ?{ (untyped waiter) -> void } -> CompositeAlarm