Class: Aws::CloudWatch::Metric
- Inherits:
-
Object
- Object
- Aws::CloudWatch::Metric
- Extended by:
- Deprecations
- Defined in:
- sig/metric.rbs,
lib/aws-sdk-cloudwatch/metric.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#dimensions ⇒ Array<Types::Dimension>
The dimensions for the metric.
- #name ⇒ String (also: #metric_name)
- #namespace ⇒ String
Actions collapse
- #get_statistics(options = {}) ⇒ Types::GetMetricStatisticsOutput
- #put_alarm(options = {}) ⇒ Alarm
- #put_data(options = {}) ⇒ EmptyStructure
Associations collapse
- #alarms(options = {}) ⇒ Alarm::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::Metric
Returns the data for this Metric.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ Metric
constructor
A new instance of Metric.
- #load ⇒ self (also: #reload)
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::CloudWatch::Client] #wait_until instead
Constructor Details
#initialize(namespace, name, options = {}) ⇒ Metric #initialize(options = {}) ⇒ Metric
Returns a new instance of Metric.
13 14 15 |
# File 'sig/metric.rbs', line 13
def initialize: (String namespace, String name, Hash[Symbol, untyped] options) -> void
| (namespace: String, name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#data ⇒ Types::Metric
Returns the data for this Aws::CloudWatch::Metric. Calls
Client#list_metrics if #data_loaded? is false.
34 |
# File 'sig/metric.rbs', line 34
def data: () -> Types::Metric
|
#data_loaded? ⇒ Boolean
37 |
# File 'sig/metric.rbs', line 37
def data_loaded?: () -> bool
|
#dimensions ⇒ Array<Types::Dimension>
The dimensions for the metric.
25 |
# File 'sig/metric.rbs', line 25
def dimensions: () -> ::Array[Types::Dimension]
|
#get_statistics(options = {}) ⇒ Types::GetMetricStatisticsOutput
41 |
# File 'sig/metric.rbs', line 41
def get_statistics: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-cloudwatch/metric.rb', line 997 def identifiers { namespace: @namespace, name: @name } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::CloudWatch::Metric.
Returns self making it possible to chain methods.
metric.reload.data
30 |
# File 'sig/metric.rbs', line 30
def load: () -> self
|
#name ⇒ String Also known as: metric_name
21 |
# File 'sig/metric.rbs', line 21
def name: () -> String
|
#namespace ⇒ String
18 |
# File 'sig/metric.rbs', line 18
def namespace: () -> String
|
#put_data(options = {}) ⇒ EmptyStructure
125 |
# File 'sig/metric.rbs', line 125
def put_data: (
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::CloudWatch::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/aws-sdk-cloudwatch/metric.rb', line 172 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |