Class: Aws::CloudWatch::Types::AlarmHistoryItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Represents the history of a specific alarm.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_contributor_attributesHash<String,String>

A map of attributes that describe the alarm contributor associated with this history item, providing context about the contributor's characteristics at the time of the event.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-cloudwatch/types.rb', line 86

class AlarmHistoryItem < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_type,
  :timestamp,
  :history_item_type,
  :history_summary,
  :history_data,
  :alarm_contributor_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_contributor_idString

The unique identifier of the alarm contributor associated with this history item, if applicable.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-cloudwatch/types.rb', line 86

class AlarmHistoryItem < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_type,
  :timestamp,
  :history_item_type,
  :history_summary,
  :history_data,
  :alarm_contributor_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_nameString

The descriptive name for the alarm.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-cloudwatch/types.rb', line 86

class AlarmHistoryItem < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_type,
  :timestamp,
  :history_item_type,
  :history_summary,
  :history_data,
  :alarm_contributor_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_typeString

The type of alarm, either metric alarm or composite alarm.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-cloudwatch/types.rb', line 86

class AlarmHistoryItem < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_type,
  :timestamp,
  :history_item_type,
  :history_summary,
  :history_data,
  :alarm_contributor_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#history_dataString

Data about the alarm, in JSON format.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-cloudwatch/types.rb', line 86

class AlarmHistoryItem < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_type,
  :timestamp,
  :history_item_type,
  :history_summary,
  :history_data,
  :alarm_contributor_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#history_item_typeString

The type of alarm history item.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-cloudwatch/types.rb', line 86

class AlarmHistoryItem < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_type,
  :timestamp,
  :history_item_type,
  :history_summary,
  :history_data,
  :alarm_contributor_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#history_summaryString

A summary of the alarm history, in text format.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-cloudwatch/types.rb', line 86

class AlarmHistoryItem < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_type,
  :timestamp,
  :history_item_type,
  :history_summary,
  :history_data,
  :alarm_contributor_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The time stamp for the alarm history item.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-cloudwatch/types.rb', line 86

class AlarmHistoryItem < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_type,
  :timestamp,
  :history_item_type,
  :history_summary,
  :history_data,
  :alarm_contributor_attributes)
  SENSITIVE = []
  include Aws::Structure
end