Class: Aws::CloudWatch::Types::CompositeAlarm
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::CompositeAlarm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
The details about a composite alarm.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions_enabled ⇒ Boolean
Indicates whether actions should be executed during any changes to the alarm state.
-
#actions_suppressed_by ⇒ String
When the value is ‘ALARM`, it means that the actions are suppressed because the suppressor alarm is in `ALARM` When the value is `WaitPeriod`, it means that the actions are suppressed because the composite alarm is waiting for the suppressor alarm to go into into the `ALARM` state.
-
#actions_suppressed_reason ⇒ String
Captures the reason for action suppression.
-
#actions_suppressor ⇒ String
Actions will be suppressed if the suppressor alarm is in the ‘ALARM` state.
-
#actions_suppressor_extension_period ⇒ Integer
The maximum time in seconds that the composite alarm waits after suppressor alarm goes out of the ‘ALARM` state.
-
#actions_suppressor_wait_period ⇒ Integer
The maximum time in seconds that the composite alarm waits for the suppressor alarm to go into the ‘ALARM` state.
-
#alarm_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the ALARM state from any other state.
-
#alarm_arn ⇒ String
The Amazon Resource Name (ARN) of the alarm.
-
#alarm_configuration_updated_timestamp ⇒ Time
The time stamp of the last update to the alarm configuration.
-
#alarm_description ⇒ String
The description of the alarm.
-
#alarm_name ⇒ String
The name of the alarm.
-
#alarm_rule ⇒ String
The rule that this alarm uses to evaluate its alarm state.
-
#insufficient_data_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state.
-
#ok_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the OK state from any other state.
-
#state_reason ⇒ String
An explanation for the alarm state, in text format.
-
#state_reason_data ⇒ String
An explanation for the alarm state, in JSON format.
-
#state_transitioned_timestamp ⇒ Time
The timestamp of the last change to the alarm’s ‘StateValue`.
-
#state_updated_timestamp ⇒ Time
Tracks the timestamp of any state update, even if ‘StateValue` doesn’t change.
-
#state_value ⇒ String
The state value for the alarm.
Instance Attribute Details
#actions_enabled ⇒ Boolean
Indicates whether actions should be executed during any changes to the alarm state.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#actions_suppressed_by ⇒ String
When the value is ‘ALARM`, it means that the actions are suppressed because the suppressor alarm is in `ALARM` When the value is `WaitPeriod`, it means that the actions are suppressed because the composite alarm is waiting for the suppressor alarm to go into into the `ALARM` state. The maximum waiting time is as specified in `ActionsSuppressorWaitPeriod`. After this time, the composite alarm performs its actions. When the value is `ExtensionPeriod`, it means that the actions are suppressed because the composite alarm is waiting after the suppressor alarm went out of the `ALARM` state. The maximum waiting time is as specified in `ActionsSuppressorExtensionPeriod`. After this time, the composite alarm performs its actions.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#actions_suppressed_reason ⇒ String
Captures the reason for action suppression.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#actions_suppressor ⇒ String
Actions will be suppressed if the suppressor alarm is in the ‘ALARM` state. `ActionsSuppressor` can be an AlarmName or an Amazon Resource Name (ARN) from an existing alarm.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#actions_suppressor_extension_period ⇒ Integer
The maximum time in seconds that the composite alarm waits after suppressor alarm goes out of the ‘ALARM` state. After this time, the composite alarm performs its actions.
‘ExtensionPeriod` is required only when `ActionsSuppressor` is specified.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#actions_suppressor_wait_period ⇒ Integer
The maximum time in seconds that the composite alarm waits for the suppressor alarm to go into the ‘ALARM` state. After this time, the composite alarm performs its actions.
‘WaitPeriod` is required only when `ActionsSuppressor` is specified.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#alarm_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the ALARM state from any other state. Each action is specified as an Amazon Resource Name (ARN).
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#alarm_arn ⇒ String
The Amazon Resource Name (ARN) of the alarm.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#alarm_configuration_updated_timestamp ⇒ Time
The time stamp of the last update to the alarm configuration.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#alarm_description ⇒ String
The description of the alarm.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#alarm_name ⇒ String
The name of the alarm.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#alarm_rule ⇒ String
The rule that this alarm uses to evaluate its alarm state.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#insufficient_data_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#ok_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
An explanation for the alarm state, in text format.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#state_reason_data ⇒ String
An explanation for the alarm state, in JSON format.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#state_transitioned_timestamp ⇒ Time
The timestamp of the last change to the alarm’s ‘StateValue`.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#state_updated_timestamp ⇒ Time
Tracks the timestamp of any state update, even if ‘StateValue` doesn’t change.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |
#state_value ⇒ String
The state value for the alarm.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 378 class CompositeAlarm < Struct.new( :actions_enabled, :alarm_actions, :alarm_arn, :alarm_configuration_updated_timestamp, :alarm_description, :alarm_name, :alarm_rule, :insufficient_data_actions, :ok_actions, :state_reason, :state_reason_data, :state_updated_timestamp, :state_value, :state_transitioned_timestamp, :actions_suppressed_by, :actions_suppressed_reason, :actions_suppressor, :actions_suppressor_wait_period, :actions_suppressor_extension_period) SENSITIVE = [] include Aws::Structure end |