Class: Aws::CloudWatch::Types::DashboardEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Represents a specific dashboard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard_arnString

The Amazon Resource Name (ARN) of the dashboard.

Returns:

  • (String)


481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-cloudwatch/types.rb', line 481

class DashboardEntry < Struct.new(
  :dashboard_name,
  :dashboard_arn,
  :last_modified,
  :size)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_nameString

The name of the dashboard.

Returns:

  • (String)


481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-cloudwatch/types.rb', line 481

class DashboardEntry < Struct.new(
  :dashboard_name,
  :dashboard_arn,
  :last_modified,
  :size)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The time stamp of when the dashboard was last modified, either by an API call or through the console. This number is expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC.

Returns:

  • (Time)


481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-cloudwatch/types.rb', line 481

class DashboardEntry < Struct.new(
  :dashboard_name,
  :dashboard_arn,
  :last_modified,
  :size)
  SENSITIVE = []
  include Aws::Structure
end

#sizeInteger

The size of the dashboard, in bytes.

Returns:

  • (Integer)


481
482
483
484
485
486
487
488
# File 'lib/aws-sdk-cloudwatch/types.rb', line 481

class DashboardEntry < Struct.new(
  :dashboard_name,
  :dashboard_arn,
  :last_modified,
  :size)
  SENSITIVE = []
  include Aws::Structure
end