Class: Aws::CloudWatch::Types::DescribeAlarmsForMetricInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::DescribeAlarmsForMetricInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<Types::Dimension>
The dimensions associated with the metric.
-
#extended_statistic ⇒ String
The percentile statistic for the metric.
-
#metric_name ⇒ String
The name of the metric.
-
#namespace ⇒ String
The namespace of the metric.
-
#period ⇒ Integer
The period, in seconds, over which the statistic is applied.
-
#statistic ⇒ String
The statistic for the metric, other than percentiles.
-
#unit ⇒ String
The unit for the metric.
Instance Attribute Details
#dimensions ⇒ Array<Types::Dimension>
The dimensions associated with the metric. If the metric has any associated dimensions, you must specify them in order for the call to succeed.
834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 834 class DescribeAlarmsForMetricInput < Struct.new( :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit) SENSITIVE = [] include Aws::Structure end |
#extended_statistic ⇒ String
The percentile statistic for the metric. Specify a value between p0.0 and p100.
834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 834 class DescribeAlarmsForMetricInput < Struct.new( :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric.
834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 834 class DescribeAlarmsForMetricInput < Struct.new( :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the metric.
834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 834 class DescribeAlarmsForMetricInput < Struct.new( :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The period, in seconds, over which the statistic is applied.
834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 834 class DescribeAlarmsForMetricInput < Struct.new( :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic for the metric, other than percentiles. For percentile statistics, use ExtendedStatistics.
834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 834 class DescribeAlarmsForMetricInput < Struct.new( :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The unit for the metric.
834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 834 class DescribeAlarmsForMetricInput < Struct.new( :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit) SENSITIVE = [] include Aws::Structure end |