Class: Aws::CloudWatch::Types::DescribeAlarmsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::DescribeAlarmsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_prefix ⇒ String
Use this parameter to filter the results of the operation to only those alarms that use a certain alarm action.
-
#alarm_name_prefix ⇒ String
An alarm name prefix.
-
#alarm_names ⇒ Array<String>
The names of the alarms to retrieve information about.
-
#alarm_types ⇒ Array<String>
Use this parameter to specify whether you want the operation to return metric alarms or composite alarms.
-
#children_of_alarm_name ⇒ String
If you use this parameter and specify the name of a composite alarm, the operation returns information about the “children” alarms of the alarm you specify.
-
#max_records ⇒ Integer
The maximum number of alarm descriptions to retrieve.
-
#next_token ⇒ String
The token returned by a previous call to indicate that there is more data available.
-
#parents_of_alarm_name ⇒ String
If you use this parameter and specify the name of a metric or composite alarm, the operation returns information about the “parent” alarms of the alarm you specify.
-
#state_value ⇒ String
Specify this parameter to receive information only about alarms that are currently in the state that you specify.
Instance Attribute Details
#action_prefix ⇒ String
Use this parameter to filter the results of the operation to only those alarms that use a certain alarm action. For example, you could specify the ARN of an SNS topic to find all alarms that send notifications to that topic.
951 952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 951 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#alarm_name_prefix ⇒ String
An alarm name prefix. If you specify this parameter, you receive information about all alarms that have names that start with this prefix.
If this parameter is specified, you cannot specify AlarmNames.
951 952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 951 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#alarm_names ⇒ Array<String>
The names of the alarms to retrieve information about.
951 952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 951 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#alarm_types ⇒ Array<String>
Use this parameter to specify whether you want the operation to return metric alarms or composite alarms. If you omit this parameter, only metric alarms are returned, even if composite alarms exist in the account.
For example, if you omit this parameter or specify MetricAlarms, the operation returns only a list of metric alarms. It does not return any composite alarms, even if composite alarms exist in the account.
If you specify CompositeAlarms, the operation returns only a list of composite alarms, and does not return any metric alarms.
951 952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 951 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#children_of_alarm_name ⇒ String
If you use this parameter and specify the name of a composite alarm, the operation returns information about the “children” alarms of the alarm you specify. These are the metric alarms and composite alarms referenced in the AlarmRule field of the composite alarm that you specify in ChildrenOfAlarmName. Information about the composite alarm that you name in ChildrenOfAlarmName is not returned.
If you specify ChildrenOfAlarmName, you cannot specify any other parameters in the request except for MaxRecords and NextToken. If you do so, you receive a validation error.
<note markdown=“1”> Only the ‘Alarm Name`, ARN, StateValue (OK/ALARM/INSUFFICIENT_DATA), and StateUpdatedTimestamp information are returned by this operation when you use this parameter. To get complete information about these alarms, perform another DescribeAlarms operation and specify the parent alarm names in the AlarmNames parameter.
</note>
951 952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 951 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of alarm descriptions to retrieve.
951 952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 951 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned by a previous call to indicate that there is more data available.
951 952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 951 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#parents_of_alarm_name ⇒ String
If you use this parameter and specify the name of a metric or composite alarm, the operation returns information about the “parent” alarms of the alarm you specify. These are the composite alarms that have AlarmRule parameters that reference the alarm named in ParentsOfAlarmName. Information about the alarm that you specify in ParentsOfAlarmName is not returned.
If you specify ParentsOfAlarmName, you cannot specify any other parameters in the request except for MaxRecords and NextToken. If you do so, you receive a validation error.
<note markdown=“1”> Only the Alarm Name and ARN are returned by this operation when you use this parameter. To get complete information about these alarms, perform another DescribeAlarms operation and specify the parent alarm names in the AlarmNames parameter.
</note>
951 952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 951 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#state_value ⇒ String
Specify this parameter to receive information only about alarms that are currently in the state that you specify.
951 952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 951 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |