Class: Aws::CloudWatch::Types::DisassociateDatasetKmsKeyInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dataset_identifierString

Specifies the identifier of the dataset from which to remove the KMS key association. For the default dataset, you can specify either default or the full dataset Amazon Resource Name (ARN) in the format arn:aws:cloudwatch:Region:account-id:dataset/default.

Returns:

  • (String)


1274
1275
1276
1277
1278
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1274

class DisassociateDatasetKmsKeyInput < Struct.new(
  :dataset_identifier)
  SENSITIVE = []
  include Aws::Structure
end