Class: Aws::CloudWatch::Types::GetAlarmMuteRuleInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::GetAlarmMuteRuleInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_mute_rule_name ⇒ String
The name of the alarm mute rule to retrieve.
Instance Attribute Details
#alarm_mute_rule_name ⇒ String
The name of the alarm mute rule to retrieve.
1303 1304 1305 1306 1307 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1303 class GetAlarmMuteRuleInput < Struct.new( :alarm_mute_rule_name) SENSITIVE = [] include Aws::Structure end |