Class: Aws::CloudWatch::Types::GetAlarmMuteRuleOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_mute_rule_arnString

The Amazon Resource Name (ARN) of the alarm mute rule.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the alarm mute rule.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end

#expire_dateTime

The date and time when the mute rule expires and is no longer evaluated.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timestampTime

The date and time when the mute rule was last updated.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end

#mute_targetsTypes::MuteTargets

Specifies which alarms this rule applies to.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end

#mute_typeString

Indicates whether the mute rule is one-time or recurring. Valid values are ONE_TIME or RECURRING.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the alarm mute rule.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end

#ruleTypes::Rule

The configuration that defines when and how long alarms are muted.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

The date and time when the mute rule becomes active. If not set, the rule is active immediately.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the alarm mute rule. Valid values are SCHEDULED, ACTIVE, or EXPIRED.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1545

class GetAlarmMuteRuleOutput < Struct.new(
  :name,
  :alarm_mute_rule_arn,
  :description,
  :rule,
  :mute_targets,
  :start_date,
  :expire_date,
  :status,
  :last_updated_timestamp,
  :mute_type)
  SENSITIVE = []
  include Aws::Structure
end