Class: Aws::CloudWatch::Types::GetDashboardOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard_arnString

The Amazon Resource Name (ARN) of the dashboard.

Returns:

  • (String)


1593
1594
1595
1596
1597
1598
1599
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1593

class GetDashboardOutput < Struct.new(
  :dashboard_arn,
  :dashboard_body,
  :dashboard_name)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_bodyString

The detailed information about the dashboard, including what widgets are included and their location on the dashboard. For more information about the DashboardBody syntax, see Dashboard Body Structure and Syntax.

Returns:

  • (String)


1593
1594
1595
1596
1597
1598
1599
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1593

class GetDashboardOutput < Struct.new(
  :dashboard_arn,
  :dashboard_body,
  :dashboard_name)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_nameString

The name of the dashboard.

Returns:

  • (String)


1593
1594
1595
1596
1597
1598
1599
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1593

class GetDashboardOutput < Struct.new(
  :dashboard_arn,
  :dashboard_body,
  :dashboard_name)
  SENSITIVE = []
  include Aws::Structure
end