Class: Aws::CloudWatch::Types::GetInsightRuleReportOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregate_valueFloat

The sum of the values from all individual contributors that match the rule.

Returns:

  • (Float)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1578

class GetInsightRuleReportOutput < Struct.new(
  :key_labels,
  :aggregation_statistic,
  :aggregate_value,
  :approximate_unique_count,
  :contributors,
  :metric_datapoints)
  SENSITIVE = []
  include Aws::Structure
end

#aggregation_statisticString

Specifies whether this rule aggregates contributor data by COUNT or SUM.

Returns:

  • (String)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1578

class GetInsightRuleReportOutput < Struct.new(
  :key_labels,
  :aggregation_statistic,
  :aggregate_value,
  :approximate_unique_count,
  :contributors,
  :metric_datapoints)
  SENSITIVE = []
  include Aws::Structure
end

#approximate_unique_countInteger

An approximate count of the unique contributors found by this rule in this time period.

Returns:

  • (Integer)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1578

class GetInsightRuleReportOutput < Struct.new(
  :key_labels,
  :aggregation_statistic,
  :aggregate_value,
  :approximate_unique_count,
  :contributors,
  :metric_datapoints)
  SENSITIVE = []
  include Aws::Structure
end

#contributorsArray<Types::InsightRuleContributor>

An array of the unique contributors found by this rule in this time period. If the rule contains multiple keys, each combination of values for the keys counts as a unique contributor.

Returns:



1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1578

class GetInsightRuleReportOutput < Struct.new(
  :key_labels,
  :aggregation_statistic,
  :aggregate_value,
  :approximate_unique_count,
  :contributors,
  :metric_datapoints)
  SENSITIVE = []
  include Aws::Structure
end

#key_labelsArray<String>

An array of the strings used as the keys for this rule. The keys are the dimensions used to classify contributors. If the rule contains more than one key, then each unique combination of values for the keys is counted as a unique contributor.

Returns:

  • (Array<String>)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1578

class GetInsightRuleReportOutput < Struct.new(
  :key_labels,
  :aggregation_statistic,
  :aggregate_value,
  :approximate_unique_count,
  :contributors,
  :metric_datapoints)
  SENSITIVE = []
  include Aws::Structure
end

#metric_datapointsArray<Types::InsightRuleMetricDatapoint>

A time series of metric data points that matches the time period in the rule request.



1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1578

class GetInsightRuleReportOutput < Struct.new(
  :key_labels,
  :aggregation_statistic,
  :aggregate_value,
  :approximate_unique_count,
  :contributors,
  :metric_datapoints)
  SENSITIVE = []
  include Aws::Structure
end