Class: Aws::CloudWatch::Types::GetMetricStreamOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the metric stream.

Returns:

  • (String)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date that the metric stream was created.

Returns:

  • (Time)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_filtersArray<Types::MetricStreamFilter>

If this array of metric namespaces is present, then these namespaces are the only metric namespaces that are not streamed by this metric stream. In this case, all other metric namespaces in the account are streamed by this metric stream.

Returns:



2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#firehose_arnString

The ARN of the Amazon Kinesis Data Firehose delivery stream that is used by this metric stream.

Returns:

  • (String)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#include_filtersArray<Types::MetricStreamFilter>

If this array of metric namespaces is present, then these namespaces are the only metric namespaces that are streamed by this metric stream.

Returns:



2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#include_linked_accounts_metricsBoolean

If this is true and this metric stream is in a monitoring account, then the stream includes metrics from source accounts that the monitoring account is linked to.

Returns:

  • (Boolean)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_dateTime

The date of the most recent update to the metric stream's configuration.

Returns:

  • (Time)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the metric stream.

Returns:

  • (String)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#output_formatString

The output format for the stream. Valid values are json, opentelemetry1.0, and opentelemetry0.7. For more information about metric stream output formats, see Metric streams output formats.

Returns:

  • (String)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that is used by this metric stream.

Returns:

  • (String)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the metric stream. The possible values are running and stopped.

Returns:

  • (String)


2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#statistics_configurationsArray<Types::MetricStreamStatisticsConfiguration>

Each entry in this array displays information about one or more metrics that include additional statistics in the metric stream. For more information about the additional statistics, see CloudWatch statistics definitions.



2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2060

class GetMetricStreamOutput < Struct.new(
  :arn,
  :name,
  :include_filters,
  :exclude_filters,
  :firehose_arn,
  :role_arn,
  :state,
  :creation_date,
  :last_update_date,
  :output_format,
  :statistics_configurations,
  :include_linked_accounts_metrics)
  SENSITIVE = []
  include Aws::Structure
end