Class: Aws::CloudWatch::Types::ListManagedInsightRulesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::ListManagedInsightRulesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in one operation.
-
#next_token ⇒ String
Include this value to get the next set of rules if the value was returned by the previous operation.
-
#resource_arn ⇒ String
The ARN of an Amazon Web Services resource that has managed Contributor Insights rules.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in one operation. If you
omit this parameter, the default number is used. The default number
is 100.
2731 2732 2733 2734 2735 2736 2737 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2731 class ListManagedInsightRulesInput < Struct.new( :resource_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Include this value to get the next set of rules if the value was returned by the previous operation.
2731 2732 2733 2734 2735 2736 2737 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2731 class ListManagedInsightRulesInput < Struct.new( :resource_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of an Amazon Web Services resource that has managed Contributor Insights rules.
2731 2732 2733 2734 2735 2736 2737 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2731 class ListManagedInsightRulesInput < Struct.new( :resource_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |