Class: Aws::CloudWatch::Types::LogAlarm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

The details about a log alarm.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_log_line_countInteger

The number of log lines from the most recent scheduled query execution that are included in alarm action notifications. Valid range is 0 through 50. A value of 0 means no log lines are included.

Returns:

  • (Integer)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#action_log_line_role_arnString

The Amazon Resource Name (ARN) of the IAM role that CloudWatch assumes to retrieve log events for inclusion in alarm action notifications. Set when ActionLogLineCount is greater than 0.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#actions_enabledBoolean

Indicates whether actions should be executed during any changes to the alarm state.

Returns:

  • (Boolean)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_actionsArray<String>

The actions to execute when this alarm transitions to the ALARM state from any other state. Each action is specified as an Amazon Resource Name (ARN).

Returns:

  • (Array<String>)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_arnString

The Amazon Resource Name (ARN) of the alarm.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_configuration_updated_timestampTime

The time stamp of the last update to the alarm configuration.

Returns:

  • (Time)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_descriptionString

The description of the alarm.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_nameString

The name of the alarm.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#comparison_operatorString

The arithmetic operation to use when comparing the aggregated query result and the threshold. The aggregated query result is used as the first operand.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_stateString

If the value of this field is EVALUATION_ERROR, it indicates configuration errors in the alarm setup that require review and correction. Refer to the StateReason field of the alarm for more details.

If the value of this field is EVALUATION_FAILURE, it indicates temporary CloudWatch issues. We recommend manual monitoring until the issue is resolved.

If the value of this field is PARTIAL_DATA, it indicates that the query returned the maximum 500 contributor groups but more matched. The alarm evaluates the available contributors, but results might be incomplete.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#insufficient_data_actionsArray<String>

The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).

Returns:

  • (Array<String>)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ok_actionsArray<String>

The actions to execute when this alarm transitions to the OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).

Returns:

  • (Array<String>)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#query_results_to_alarmInteger

The number of query results, out of the most recent QueryResultsToEvaluate results, that must breach the threshold to trigger the alarm to transition to ALARM (the M in M-of-N evaluation).

Returns:

  • (Integer)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#query_results_to_evaluateInteger

The number of most recent scheduled query results that the alarm evaluates against the threshold (the N in M-of-N evaluation).

Returns:

  • (Integer)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_query_configurationTypes::ScheduledQueryConfiguration

The configuration of the underlying CloudWatch Logs scheduled query, including the query string, log groups, schedule, aggregation expression, and the ARN of the managed scheduled query.



3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

An explanation for the alarm state, in text format.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#state_reason_dataString

An explanation for the alarm state, in JSON format.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#state_transitioned_timestampTime

The date and time that the alarm's StateValue most recently changed.

Returns:

  • (Time)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#state_updated_timestampTime

The time stamp of the last update to the value of either the StateValue or EvaluationState parameters.

Returns:

  • (Time)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#state_valueString

The state value for the alarm.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#thresholdFloat

The value to compare with the aggregated query result.

Returns:

  • (Float)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#treat_missing_dataString

How this alarm handles missing data points. Valid values are breaching, notBreaching, ignore, and missing.

Returns:

  • (String)


3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#warm_up_configurationTypes::WarmUpConfiguration

The warm-up configuration for the alarm. A warm-up period delays alarm evaluation after you create or update the alarm. During the warm-up period, the alarm stays in INSUFFICIENT_DATA and does not perform alarm actions.

For more information, see Alarm warm-up periods in the Amazon CloudWatch User Guide.



3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3071

class LogAlarm < Struct.new(
  :alarm_name,
  :alarm_arn,
  :alarm_description,
  :alarm_configuration_updated_timestamp,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :state_value,
  :state_reason,
  :state_reason_data,
  :state_updated_timestamp,
  :scheduled_query_configuration,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :state_transitioned_timestamp,
  :evaluation_state,
  :action_log_line_count,
  :action_log_line_role_arn,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end