Class: Aws::CloudWatch::Types::MessageData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

A message returned by the GetMetricDataAPI, including a code and a description.

If a cross-Region GetMetricData operation fails with a code of Forbidden and a value of Authentication too complex to retrieve cross region data, you can correct the problem by running the GetMetricData operation in the same Region where the metric data is.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code or status code associated with the message.

Returns:

  • (String)


3118
3119
3120
3121
3122
3123
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3118

class MessageData < Struct.new(
  :code,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The message text.

Returns:

  • (String)


3118
3119
3120
3121
3122
3123
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3118

class MessageData < Struct.new(
  :code,
  :value)
  SENSITIVE = []
  include Aws::Structure
end