Class: Aws::CloudWatch::Types::MetricAlarm
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::MetricAlarm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
The details about a metric alarm.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions_enabled ⇒ Boolean
Indicates whether actions should be executed during any changes to the alarm state.
-
#alarm_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the ‘ALARM` state from any other state.
-
#alarm_arn ⇒ String
The Amazon Resource Name (ARN) of the alarm.
-
#alarm_configuration_updated_timestamp ⇒ Time
The time stamp of the last update to the alarm configuration.
-
#alarm_description ⇒ String
The description of the alarm.
-
#alarm_name ⇒ String
The name of the alarm.
-
#comparison_operator ⇒ String
The arithmetic operation to use when comparing the specified statistic and threshold.
-
#datapoints_to_alarm ⇒ Integer
The number of data points that must be breaching to trigger the alarm.
-
#dimensions ⇒ Array<Types::Dimension>
The dimensions for the metric associated with the alarm.
-
#evaluate_low_sample_count_percentile ⇒ String
Used only for alarms based on percentiles.
-
#evaluation_criteria ⇒ Types::EvaluationCriteria
The evaluation criteria for the alarm.
-
#evaluation_interval ⇒ Integer
The frequency, in seconds, at which the alarm is evaluated.
-
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
-
#evaluation_state ⇒ String
If the value of this field is ‘PARTIAL_DATA`, it indicates that not all the available data was able to be retrieved due to quota limitations.
-
#extended_statistic ⇒ String
The percentile statistic for the metric associated with the alarm.
-
#insufficient_data_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the ‘INSUFFICIENT_DATA` state from any other state.
-
#metric_name ⇒ String
The name of the metric associated with the alarm, if this is an alarm based on a single metric.
-
#metrics ⇒ Array<Types::MetricDataQuery>
An array of MetricDataQuery structures, used in an alarm based on a metric math expression.
-
#namespace ⇒ String
The namespace of the metric associated with the alarm.
-
#ok_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the ‘OK` state from any other state.
-
#period ⇒ Integer
The period, in seconds, over which the statistic is applied.
-
#state_reason ⇒ String
An explanation for the alarm state, in text format.
-
#state_reason_data ⇒ String
An explanation for the alarm state, in JSON format.
-
#state_transitioned_timestamp ⇒ Time
The date and time that the alarm’s ‘StateValue` most recently changed.
-
#state_updated_timestamp ⇒ Time
The time stamp of the last update to the value of either the ‘StateValue` or `EvaluationState` parameters.
-
#state_value ⇒ String
The state value for the alarm.
-
#statistic ⇒ String
The statistic for the metric associated with the alarm, other than percentile.
-
#threshold ⇒ Float
The value to compare with the specified statistic.
-
#threshold_metric_id ⇒ String
In an alarm based on an anomaly detection model, this is the ID of the ‘ANOMALY_DETECTION_BAND` function used as the threshold for the alarm.
-
#treat_missing_data ⇒ String
Sets how this alarm is to handle missing data points.
-
#unit ⇒ String
The unit of the metric associated with the alarm.
Instance Attribute Details
#actions_enabled ⇒ Boolean
Indicates whether actions should be executed during any changes to the alarm state.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#alarm_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the ‘ALARM` state from any other state. Each action is specified as an Amazon Resource Name (ARN).
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#alarm_arn ⇒ String
The Amazon Resource Name (ARN) of the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#alarm_configuration_updated_timestamp ⇒ Time
The time stamp of the last update to the alarm configuration.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#alarm_description ⇒ String
The description of the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#alarm_name ⇒ String
The name of the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#comparison_operator ⇒ String
The arithmetic operation to use when comparing the specified statistic and threshold. The specified statistic value is used as the first operand.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#datapoints_to_alarm ⇒ Integer
The number of data points that must be breaching to trigger the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#dimensions ⇒ Array<Types::Dimension>
The dimensions for the metric associated with the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#evaluate_low_sample_count_percentile ⇒ String
Used only for alarms based on percentiles. If ‘ignore`, the alarm state does not change during periods with too few data points to be statistically significant. If `evaluate` or this parameter is not used, the alarm is always evaluated and possibly changes state no matter how many data points are available.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#evaluation_criteria ⇒ Types::EvaluationCriteria
The evaluation criteria for the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#evaluation_interval ⇒ Integer
The frequency, in seconds, at which the alarm is evaluated.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#evaluation_state ⇒ String
If the value of this field is ‘PARTIAL_DATA`, it indicates that not all the available data was able to be retrieved due to quota limitations. For more information, see [Create alarms on Metrics Insights queries].
If the value of this field is ‘EVALUATION_ERROR`, it indicates configuration errors in alarm setup that require review and correction. Refer to StateReason field of the alarm for more details.
If the value of this field is ‘EVALUATION_FAILURE`, it indicates temporary CloudWatch issues. We recommend manual monitoring until the issue is resolved
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Create_Metrics_Insights_Alarm.html
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#extended_statistic ⇒ String
The percentile statistic for the metric associated with the alarm. Specify a value between p0.0 and p100.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#insufficient_data_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the ‘INSUFFICIENT_DATA` state from any other state. Each action is specified as an Amazon Resource Name (ARN).
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric associated with the alarm, if this is an alarm based on a single metric.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<Types::MetricDataQuery>
An array of MetricDataQuery structures, used in an alarm based on a metric math expression. Each structure either retrieves a metric or performs a math expression. One item in the Metrics array is the math expression that the alarm watches. This expression by designated by having ‘ReturnData` set to true.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the metric associated with the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#ok_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the ‘OK` state from any other state. Each action is specified as an Amazon Resource Name (ARN).
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The period, in seconds, over which the statistic is applied.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
An explanation for the alarm state, in text format.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#state_reason_data ⇒ String
An explanation for the alarm state, in JSON format.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#state_transitioned_timestamp ⇒ Time
The date and time that the alarm’s ‘StateValue` most recently changed.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#state_updated_timestamp ⇒ Time
The time stamp of the last update to the value of either the ‘StateValue` or `EvaluationState` parameters.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#state_value ⇒ String
The state value for the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic for the metric associated with the alarm, other than percentile. For percentile statistics, use ‘ExtendedStatistic`.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
The value to compare with the specified statistic.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#threshold_metric_id ⇒ String
In an alarm based on an anomaly detection model, this is the ID of the ‘ANOMALY_DETECTION_BAND` function used as the threshold for the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#treat_missing_data ⇒ String
Sets how this alarm is to handle missing data points. The valid values are ‘breaching`, `notBreaching`, `ignore`, and `missing`. For more information, see [Configuring how CloudWatch alarms treat missing data].
If this parameter is omitted, the default behavior of ‘missing` is used.
<note markdown=“1”> This parameter is not applicable to PromQL alarms.
</note>
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The unit of the metric associated with the alarm.
3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3010 class MetricAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :metric_name, :namespace, :statistic, :extended_statistic, :dimensions, :period, :unit, :evaluation_periods, :datapoints_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :evaluate_low_sample_count_percentile, :metrics, :threshold_metric_id, :evaluation_state, :state_transitioned_timestamp, :evaluation_criteria, :evaluation_interval) SENSITIVE = [] include Aws::Structure end |