Class: Aws::CloudWatch::Types::MetricDataResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::MetricDataResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
A GetMetricData call returns an array of MetricDataResult
structures. Each of these structures includes the data points for that
metric, along with the timestamps of those data points and other
identifying information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The short name you specified to represent this metric.
-
#label ⇒ String
The human-readable label associated with the data.
-
#messages ⇒ Array<Types::MessageData>
A list of messages with additional information about the data returned.
-
#status_code ⇒ String
The status of the returned data.
-
#timestamps ⇒ Array<Time>
The timestamps for the data points, formatted in Unix timestamp format.
-
#values ⇒ Array<Float>
The data points for the metric corresponding to
Timestamps.
Instance Attribute Details
#id ⇒ String
The short name you specified to represent this metric.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3570 class MetricDataResult < Struct.new( :id, :label, :timestamps, :values, :status_code, :messages) SENSITIVE = [] include Aws::Structure end |
#label ⇒ String
The human-readable label associated with the data.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3570 class MetricDataResult < Struct.new( :id, :label, :timestamps, :values, :status_code, :messages) SENSITIVE = [] include Aws::Structure end |
#messages ⇒ Array<Types::MessageData>
A list of messages with additional information about the data returned.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3570 class MetricDataResult < Struct.new( :id, :label, :timestamps, :values, :status_code, :messages) SENSITIVE = [] include Aws::Structure end |
#status_code ⇒ String
The status of the returned data. Complete indicates that all data
points in the requested time range were returned. PartialData
means that an incomplete set of data points were returned. You can
use the NextToken value that was returned and repeat your request
to get more data points. NextToken is not returned if you are
performing a math expression. InternalError indicates that an
error occurred. Retry your request using NextToken, if present.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3570 class MetricDataResult < Struct.new( :id, :label, :timestamps, :values, :status_code, :messages) SENSITIVE = [] include Aws::Structure end |
#timestamps ⇒ Array<Time>
The timestamps for the data points, formatted in Unix timestamp format. The number of timestamps always matches the number of values and the value for Timestamps[x] is Values[x].
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3570 class MetricDataResult < Struct.new( :id, :label, :timestamps, :values, :status_code, :messages) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<Float>
The data points for the metric corresponding to Timestamps. The
number of values always matches the number of timestamps and the
timestamp for Values[x] is Timestamps[x].
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3570 class MetricDataResult < Struct.new( :id, :label, :timestamps, :values, :status_code, :messages) SENSITIVE = [] include Aws::Structure end |