Class: Aws::CloudWatch::Types::PutAnomalyDetectorInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::PutAnomalyDetectorInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::AnomalyDetectorConfiguration
The configuration specifies details about how the anomaly detection model is to be trained, including time ranges to exclude when training and updating the model.
-
#dimensions ⇒ Array<Types::Dimension>
The metric dimensions to create the anomaly detection model for.
-
#metric_characteristics ⇒ Types::MetricCharacteristics
Use this object to include parameters to provide information about your metric to CloudWatch to help it build more accurate anomaly detection models.
-
#metric_math_anomaly_detector ⇒ Types::MetricMathAnomalyDetector
The metric math anomaly detector to be created.
-
#metric_name ⇒ String
The name of the metric to create the anomaly detection model for.
-
#namespace ⇒ String
The namespace of the metric to create the anomaly detection model for.
-
#single_metric_anomaly_detector ⇒ Types::SingleMetricAnomalyDetector
A single metric anomaly detector to be created.
-
#stat ⇒ String
The statistic to use for the metric and the anomaly detection model.
Instance Attribute Details
#configuration ⇒ Types::AnomalyDetectorConfiguration
The configuration specifies details about how the anomaly detection model is to be trained, including time ranges to exclude when training and updating the model. You can specify as many as 10 time ranges.
The configuration can also include the time zone to use for the metric.
4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4229 class PutAnomalyDetectorInput < Struct.new( :namespace, :metric_name, :dimensions, :stat, :configuration, :metric_characteristics, :single_metric_anomaly_detector, :metric_math_anomaly_detector) SENSITIVE = [] include Aws::Structure end |
#dimensions ⇒ Array<Types::Dimension>
The metric dimensions to create the anomaly detection model for.
4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4229 class PutAnomalyDetectorInput < Struct.new( :namespace, :metric_name, :dimensions, :stat, :configuration, :metric_characteristics, :single_metric_anomaly_detector, :metric_math_anomaly_detector) SENSITIVE = [] include Aws::Structure end |
#metric_characteristics ⇒ Types::MetricCharacteristics
Use this object to include parameters to provide information about
your metric to CloudWatch to help it build more accurate anomaly
detection models. Currently, it includes the PeriodicSpikes
parameter.
4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4229 class PutAnomalyDetectorInput < Struct.new( :namespace, :metric_name, :dimensions, :stat, :configuration, :metric_characteristics, :single_metric_anomaly_detector, :metric_math_anomaly_detector) SENSITIVE = [] include Aws::Structure end |
#metric_math_anomaly_detector ⇒ Types::MetricMathAnomalyDetector
The metric math anomaly detector to be created.
When using MetricMathAnomalyDetector, you cannot include the
following parameters in the same operation:
-
Dimensions -
MetricName -
Namespace -
Stat -
the
SingleMetricAnomalyDetectorparameters ofPutAnomalyDetectorInput
Instead, specify the metric math anomaly detector attributes as part
of the property MetricMathAnomalyDetector.
4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4229 class PutAnomalyDetectorInput < Struct.new( :namespace, :metric_name, :dimensions, :stat, :configuration, :metric_characteristics, :single_metric_anomaly_detector, :metric_math_anomaly_detector) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric to create the anomaly detection model for.
4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4229 class PutAnomalyDetectorInput < Struct.new( :namespace, :metric_name, :dimensions, :stat, :configuration, :metric_characteristics, :single_metric_anomaly_detector, :metric_math_anomaly_detector) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the metric to create the anomaly detection model for.
4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4229 class PutAnomalyDetectorInput < Struct.new( :namespace, :metric_name, :dimensions, :stat, :configuration, :metric_characteristics, :single_metric_anomaly_detector, :metric_math_anomaly_detector) SENSITIVE = [] include Aws::Structure end |
#single_metric_anomaly_detector ⇒ Types::SingleMetricAnomalyDetector
A single metric anomaly detector to be created.
When using SingleMetricAnomalyDetector, you cannot include the
following parameters in the same operation:
-
Dimensions -
MetricName -
Namespace -
Stat -
the
MetricMathAnomalyDetectorparameters ofPutAnomalyDetectorInput
Instead, specify the single metric anomaly detector attributes as
part of the property SingleMetricAnomalyDetector.
4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4229 class PutAnomalyDetectorInput < Struct.new( :namespace, :metric_name, :dimensions, :stat, :configuration, :metric_characteristics, :single_metric_anomaly_detector, :metric_math_anomaly_detector) SENSITIVE = [] include Aws::Structure end |
#stat ⇒ String
The statistic to use for the metric and the anomaly detection model.
4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4229 class PutAnomalyDetectorInput < Struct.new( :namespace, :metric_name, :dimensions, :stat, :configuration, :metric_characteristics, :single_metric_anomaly_detector, :metric_math_anomaly_detector) SENSITIVE = [] include Aws::Structure end |