Class: Aws::CloudWatch::Types::PutAnomalyDetectorOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::PutAnomalyDetectorOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anomaly_detector_id ⇒ String
The unique identifier of the anomaly detector that you created or updated.
Instance Attribute Details
#anomaly_detector_id ⇒ String
The unique identifier of the anomaly detector that you created or updated.
4219 4220 4221 4222 4223 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4219 class PutAnomalyDetectorOutput < Struct.new( :anomaly_detector_id) SENSITIVE = [] include Aws::Structure end |