Class: Aws::CloudWatch::Types::PutDashboardInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::PutDashboardInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dashboard_body ⇒ String
The detailed information about the dashboard in JSON format, including the widgets to include and their location on the dashboard.
-
#dashboard_name ⇒ String
The name of the dashboard.
-
#tags ⇒ Array<Types::Tag>
A list of key-value pairs to associate with the dashboard.
Instance Attribute Details
#dashboard_body ⇒ String
The detailed information about the dashboard in JSON format, including the widgets to include and their location on the dashboard. This parameter is required.
For more information about the syntax, see [Dashboard Body Structure and Syntax].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/CloudWatch-Dashboard-Body-Structure.html
4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4234 class PutDashboardInput < Struct.new( :dashboard_name, :dashboard_body, :tags) SENSITIVE = [] include Aws::Structure end |
#dashboard_name ⇒ String
The name of the dashboard. If a dashboard with this name already exists, this call modifies that dashboard, replacing its current contents. Otherwise, a new dashboard is created. The maximum length is 255, and valid characters are A-Z, a-z, 0-9, “-”, and “_”. This parameter is required.
4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4234 class PutDashboardInput < Struct.new( :dashboard_name, :dashboard_body, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of key-value pairs to associate with the dashboard. You can associate as many as 50 tags with a dashboard.
Tags can help you organize and categorize your dashboards. You can also use them to scope user permissions by granting a user permission to access or change only dashboards with certain tag values.
You can use this parameter only when creating a new dashboard. If you specify ‘Tags` when updating an existing dashboard, the tag updates are ignored. To add or update tags on an existing dashboard, use [TagResource]. To remove tags, use [UntagResource].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_TagResource.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_UntagResource.html
4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4234 class PutDashboardInput < Struct.new( :dashboard_name, :dashboard_body, :tags) SENSITIVE = [] include Aws::Structure end |