Class: Aws::CloudWatch::Types::PutDashboardOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard_validation_messagesArray<Types::DashboardValidationMessage>

If the input for PutDashboard was correct and the dashboard was successfully created or modified, this result is empty.

If this result includes only warning messages, then the input was valid enough for the dashboard to be created or modified, but some elements of the dashboard might not render.

If this result includes error messages, the input was not valid and the operation failed.



4539
4540
4541
4542
4543
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4539

class PutDashboardOutput < Struct.new(
  :dashboard_validation_messages)
  SENSITIVE = []
  include Aws::Structure
end