Class: Aws::CloudWatch::Types::PutLogAlarmInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_log_line_countInteger

The number of log lines from the most recent scheduled query execution to include in alarm action notifications. Valid range is 0 through 50. The default is 0, which means no log lines are included.

Returns:

  • (Integer)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#action_log_line_role_arnString

The Amazon Resource Name (ARN) of an IAM role that CloudWatch assumes to retrieve log events for inclusion in alarm action notifications. Required when ActionLogLineCount is greater than 0.

Returns:

  • (String)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#actions_enabledBoolean

Indicates whether actions should be executed during any changes to the alarm state. The default is true.

Returns:

  • (Boolean)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_actionsArray<String>

The actions to execute when this alarm transitions to the ALARM state from any other state. Each action is specified as an Amazon Resource Name (ARN).

Valid Values:

Amazon SNS actions:

arn:aws:sns:region:account-id:sns-topic-name

Lambda actions:

  • Invoke the latest version of a Lambda function: arn:aws:lambda:region:account-id:function:function-name

  • Invoke a specific version of a Lambda function: arn:aws:lambda:region:account-id:function:function-name:version-number

  • Invoke a function by using an alias Lambda function: arn:aws:lambda:region:account-id:function:function-name:alias-name

Systems Manager actions:

arn:aws:ssm:region:account-id:opsitem:severity

Returns:

  • (Array<String>)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_descriptionString

The description for the alarm.

Returns:

  • (String)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_nameString

The name for the alarm. This name must be unique within the Amazon Web Services account and Region.

Returns:

  • (String)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#comparison_operatorString

The arithmetic operation to use when comparing the aggregated query result and the threshold. The aggregated query result is used as the first operand. Valid values are GreaterThanThreshold, GreaterThanOrEqualToThreshold, LessThanThreshold, and LessThanOrEqualToThreshold.

Returns:

  • (String)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#insufficient_data_actionsArray<String>

The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).

Valid Values:

Amazon SNS actions:

arn:aws:sns:region:account-id:sns-topic-name

Lambda actions:

  • Invoke the latest version of a Lambda function: arn:aws:lambda:region:account-id:function:function-name

  • Invoke a specific version of a Lambda function: arn:aws:lambda:region:account-id:function:function-name:version-number

  • Invoke a function by using an alias Lambda function: arn:aws:lambda:region:account-id:function:function-name:alias-name

Returns:

  • (Array<String>)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ok_actionsArray<String>

The actions to execute when this alarm transitions to the OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).

Valid Values:

Amazon SNS actions:

arn:aws:sns:region:account-id:sns-topic-name

Lambda actions:

  • Invoke the latest version of a Lambda function: arn:aws:lambda:region:account-id:function:function-name

  • Invoke a specific version of a Lambda function: arn:aws:lambda:region:account-id:function:function-name:version-number

  • Invoke a function by using an alias Lambda function: arn:aws:lambda:region:account-id:function:function-name:alias-name

Returns:

  • (Array<String>)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#query_results_to_alarmInteger

The number of query results, out of the most recent QueryResultsToEvaluate results, that must breach the threshold to trigger the alarm to transition to ALARM (the M in M-of-N evaluation). Must be less than or equal to QueryResultsToEvaluate.

Returns:

  • (Integer)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#query_results_to_evaluateInteger

The number of most recent scheduled query results to evaluate against the threshold (the N in M-of-N evaluation). Valid range is 1 through 100.

Returns:

  • (Integer)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_query_configurationTypes::ScheduledQueryConfiguration

The configuration of the underlying CloudWatch Logs scheduled query that this alarm evaluates, including the query string, log groups, schedule, and aggregation expression.



4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of key-value pairs to associate with the alarm. You can use tags to categorize and manage your alarms.

Returns:



4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#thresholdFloat

The value to compare with the aggregated query result.

Returns:

  • (Float)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#treat_missing_dataString

Sets how this alarm is to handle missing data points. Valid values are breaching, notBreaching, ignore, and missing. If this parameter is omitted, the default behavior of missing is used.

Returns:

  • (String)


4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#warm_up_configurationTypes::WarmUpConfiguration

The warm-up configuration for the alarm. A warm-up period delays alarm evaluation after you create or update the alarm. The warm-up period reduces alarm noise from missing data while a new resource or service starts publishing data.

For more information, see Alarm warm-up periods in the Amazon CloudWatch User Guide.



4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4786

class PutLogAlarmInput < Struct.new(
  :alarm_name,
  :alarm_description,
  :scheduled_query_configuration,
  :action_log_line_count,
  :action_log_line_role_arn,
  :actions_enabled,
  :ok_actions,
  :alarm_actions,
  :insufficient_data_actions,
  :query_results_to_evaluate,
  :query_results_to_alarm,
  :threshold,
  :comparison_operator,
  :treat_missing_data,
  :tags,
  :warm_up_configuration)
  SENSITIVE = []
  include Aws::Structure
end