Class: Aws::CloudWatch::Types::ResourceConflict

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

The operation could not be completed because the request conflicts with the current state of the alarm or its underlying scheduled query resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


5451
5452
5453
5454
5455
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5451

class ResourceConflict < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end