Class: Aws::CloudWatch::Types::ScheduleConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Contains the schedule expression and time-range offsets that define when a scheduled query runs and what time range each execution covers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_time_offsetInteger

The offset, in seconds, before the scheduled execution time at which the query time range ends. Must be non-negative and less than StartTimeOffset. The default is 0.

Returns:

  • (Integer)


5635
5636
5637
5638
5639
5640
5641
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5635

class ScheduleConfiguration < Struct.new(
  :schedule_expression,
  :start_time_offset,
  :end_time_offset)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_expressionString

The schedule expression that defines how often the underlying CloudWatch Logs scheduled query runs. Specify a rate() expression, for example rate(5 minutes).

Returns:

  • (String)


5635
5636
5637
5638
5639
5640
5641
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5635

class ScheduleConfiguration < Struct.new(
  :schedule_expression,
  :start_time_offset,
  :end_time_offset)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_offsetInteger

The offset, in seconds, before the scheduled execution time at which the query time range begins. For example, an offset of 360 (6 minutes) on a query running at 12:05:00 starts the query time range at 11:59:00.

Returns:

  • (Integer)


5635
5636
5637
5638
5639
5640
5641
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5635

class ScheduleConfiguration < Struct.new(
  :schedule_expression,
  :start_time_offset,
  :end_time_offset)
  SENSITIVE = []
  include Aws::Structure
end