Class: Aws::CloudWatch::Types::ScheduledQueryConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

The configuration of the CloudWatch Logs scheduled query that backs a log alarm.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_expressionString

The expression that defines how to aggregate query results into one or more scalar values for alarm evaluation. For example, count(*) or avg(latency) by host | sort desc. Length constraints: minimum 1 character, maximum 2048 characters.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5689

class ScheduledQueryConfiguration < Struct.new(
  :query_string,
  :log_group_identifiers,
  :query_arn,
  :scheduled_query_role_arn,
  :schedule_configuration,
  :aggregation_expression,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_identifiersArray<String>

The log groups to query. Each entry can be a log group name or ARN. Use the ARN form when querying log groups in a different account (for example, when running cross-account queries from a monitoring account). The list must contain between 1 and 50 entries.

Returns:

  • (Array<String>)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5689

class ScheduledQueryConfiguration < Struct.new(
  :query_string,
  :log_group_identifiers,
  :query_arn,
  :scheduled_query_role_arn,
  :schedule_configuration,
  :aggregation_expression,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_arnString

The Amazon Resource Name (ARN) of the CloudWatch Logs scheduled query that the alarm uses. This field is populated in DescribeAlarms responses.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5689

class ScheduledQueryConfiguration < Struct.new(
  :query_string,
  :log_group_identifiers,
  :query_arn,
  :scheduled_query_role_arn,
  :schedule_configuration,
  :aggregation_expression,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The CloudWatch Logs query to execute on each scheduled run. Length constraints: maximum of 10,000 characters.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5689

class ScheduledQueryConfiguration < Struct.new(
  :query_string,
  :log_group_identifiers,
  :query_arn,
  :scheduled_query_role_arn,
  :schedule_configuration,
  :aggregation_expression,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_configurationTypes::ScheduleConfiguration

The schedule and time-range offset configuration for the underlying scheduled query.



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5689

class ScheduledQueryConfiguration < Struct.new(
  :query_string,
  :log_group_identifiers,
  :query_arn,
  :scheduled_query_role_arn,
  :schedule_configuration,
  :aggregation_expression,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_query_role_arnString

The Amazon Resource Name (ARN) of the IAM role that CloudWatch assumes when executing the scheduled query against the configured log groups.

Returns:

  • (String)


5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5689

class ScheduledQueryConfiguration < Struct.new(
  :query_string,
  :log_group_identifiers,
  :query_arn,
  :scheduled_query_role_arn,
  :schedule_configuration,
  :aggregation_expression,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of key-value pairs to associate with the underlying scheduled query resource.

Returns:



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5689

class ScheduledQueryConfiguration < Struct.new(
  :query_string,
  :log_group_identifiers,
  :query_arn,
  :scheduled_query_role_arn,
  :schedule_configuration,
  :aggregation_expression,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end