Class: Aws::CloudWatch::Types::SetAlarmStateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::SetAlarmStateInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_name ⇒ String
The name of the alarm.
-
#state_reason ⇒ String
The reason that this alarm is set to this specific state, in text format.
-
#state_reason_data ⇒ String
The reason that this alarm is set to this specific state, in JSON format.
-
#state_value ⇒ String
The value of the state.
Instance Attribute Details
#alarm_name ⇒ String
The name of the alarm.
5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5290 class SetAlarmStateInput < Struct.new( :alarm_name, :state_value, :state_reason, :state_reason_data) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason that this alarm is set to this specific state, in text format.
5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5290 class SetAlarmStateInput < Struct.new( :alarm_name, :state_value, :state_reason, :state_reason_data) SENSITIVE = [] include Aws::Structure end |
#state_reason_data ⇒ String
The reason that this alarm is set to this specific state, in JSON format.
For SNS or EC2 alarm actions, this is just informational. But for EC2 Auto Scaling or application Auto Scaling alarm actions, the Auto Scaling policy uses the information in this field to take the correct action.
5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5290 class SetAlarmStateInput < Struct.new( :alarm_name, :state_value, :state_reason, :state_reason_data) SENSITIVE = [] include Aws::Structure end |
#state_value ⇒ String
The value of the state.
5290 5291 5292 5293 5294 5295 5296 5297 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5290 class SetAlarmStateInput < Struct.new( :alarm_name, :state_value, :state_reason, :state_reason_data) SENSITIVE = [] include Aws::Structure end |