Class: Aws::CloudWatch::Types::SlidingWindow Private

Inherits:
EmptyStructure
  • Object
show all
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

An evaluation window that advances each time the alarm is evaluated, forming a rolling time window. This is the default evaluation window. A sliding window has no additional configuration options.

Choose a sliding window when you need the fastest detection and the calendar boundaries of the data don't matter, such as for continuous performance, latency, or resource-exhaustion monitoring.