Class: Aws::CloudWatch::Types::StartMetricStreamsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#namesArray<String>

The array of the names of metric streams to start streaming.

This is an “all or nothing” operation. If you do not have permission to access all of the metric streams that you list here, then none of the streams that you list in the operation will start streaming.

Returns:

  • (Array<String>)


5050
5051
5052
5053
5054
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5050

class StartMetricStreamsInput < Struct.new(
  :names)
  SENSITIVE = []
  include Aws::Structure
end