Class: Aws::CloudWatch::Waiters::AlarmExists

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-cloudwatch/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ AlarmExists

Returns a new instance of AlarmExists.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


87
88
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 87

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



111
112
113
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 111

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeAlarmsOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :alarm_names (Array<String>)

    The names of the alarms to retrieve information about.

  • :alarm_name_prefix (String)

    An alarm name prefix. If you specify this parameter, you receive information about all alarms that have names that start with this prefix.

    If this parameter is specified, you cannot specify AlarmNames.

  • :alarm_types (Array<String>)

    Use this parameter to specify whether you want the operation to return metric alarms, composite alarms, or log alarms. If you omit this parameter, only metric alarms are returned, even if composite alarms or log alarms exist in the account.

    For example, if you omit this parameter or specify MetricAlarms, the operation returns only a list of metric alarms. It does not return any composite alarms or log alarms, even if they exist in the account.

    If you specify CompositeAlarms, the operation returns only a list of composite alarms, and does not return any metric alarms or log alarms.

    If you specify LogAlarms, the operation returns only a list of log alarms, and does not return any metric alarms or composite alarms.

  • :children_of_alarm_name (String)

    If you use this parameter and specify the name of a composite alarm, the operation returns information about the "children" alarms of the alarm you specify. These are the metric alarms and composite alarms referenced in the AlarmRule field of the composite alarm that you specify in ChildrenOfAlarmName. Information about the composite alarm that you name in ChildrenOfAlarmName is not returned.

    If you specify ChildrenOfAlarmName, you cannot specify any other parameters in the request except for MaxRecords and NextToken. If you do so, you receive a validation error.

    Only the Alarm Name, ARN, StateValue (OK/ALARM/INSUFFICIENT_DATA), and StateUpdatedTimestamp information are returned by this operation when you use this parameter. To get complete information about these alarms, perform another DescribeAlarms operation and specify the parent alarm names in the AlarmNames parameter.

  • :parents_of_alarm_name (String)

    If you use this parameter and specify the name of a metric or composite alarm, the operation returns information about the "parent" alarms of the alarm you specify. These are the composite alarms that have AlarmRule parameters that reference the alarm named in ParentsOfAlarmName. Information about the alarm that you specify in ParentsOfAlarmName is not returned.

    If you specify ParentsOfAlarmName, you cannot specify any other parameters in the request except for MaxRecords and NextToken. If you do so, you receive a validation error.

    Only the Alarm Name and ARN are returned by this operation when you use this parameter. To get complete information about these alarms, perform another DescribeAlarms operation and specify the parent alarm names in the AlarmNames parameter.

  • :state_value (String)

    Specify this parameter to receive information only about alarms that are currently in the state that you specify.

  • :action_prefix (String)

    Use this parameter to filter the results of the operation to only those alarms that use a certain alarm action. For example, you could specify the ARN of an SNS topic to find all alarms that send notifications to that topic.

  • :max_records (Integer)

    The maximum number of alarm descriptions to retrieve.

  • :next_token (String)

    The token returned by a previous call to indicate that there is more data available.

Returns:



106
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 106

def wait: (