Class: Aws::CloudWatch::Waiters::AlarmMuteRuleExists
- Inherits:
-
Object
- Object
- Aws::CloudWatch::Waiters::AlarmMuteRuleExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-cloudwatch/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AlarmMuteRuleExists
constructor
A new instance of AlarmMuteRuleExists.
-
#wait(params = {}) ⇒ Types::GetAlarmMuteRuleOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AlarmMuteRuleExists
Returns a new instance of AlarmMuteRuleExists.
123 124 |
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 123
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
153 154 155 |
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 153 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetAlarmMuteRuleOutput
Returns a response object which responds to the following methods:
- #name => String
- #alarm_mute_rule_arn => String
- #description => String
- #rule => Types::Rule
- #mute_targets => Types::MuteTargets
- #start_date => Time
- #expire_date => Time
- #status => String
- #last_updated_timestamp => Time
- #mute_type => String
148 |
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 148
def wait: (
|