Class: Aws::CloudWatch::Resource
- Inherits:
-
Object
- Object
- Aws::CloudWatch::Resource
- Defined in:
- sig/resource.rbs,
lib/aws-sdk-cloudwatch/resource.rb
Overview
This class provides a resource oriented interface for CloudWatch. To create a resource object:
resource = Aws::CloudWatch::Resource.new(region: 'us-west-2')
You can supply a client object with custom configuration that will be used for all resource operations.
If you do not pass :client, a default client will be constructed.
client = Aws::CloudWatch::Client.new(region: 'us-west-2')
resource = Aws::CloudWatch::Resource.new(client: client)
Associations collapse
- #alarm(name) ⇒ Alarm
- #alarms(options = {}) ⇒ Alarm::Collection
- #composite_alarm(name) ⇒ CompositeAlarm
- #composite_alarms(options = {}) ⇒ CompositeAlarm::Collection
- #metric(namespace, name) ⇒ Metric
- #metrics(options = {}) ⇒ Metric::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#initialize(options = {}) ⇒ Resource
constructor
A new instance of Resource.
Constructor Details
#initialize(options = {}) ⇒ Resource
Returns a new instance of Resource.
13 |
# File 'sig/resource.rbs', line 13
def initialize: (
|
Instance Method Details
#composite_alarm(name) ⇒ CompositeAlarm
101 |
# File 'sig/resource.rbs', line 101
def composite_alarm: (String name) -> CompositeAlarm
|
#composite_alarms(options = {}) ⇒ CompositeAlarm::Collection
104 |
# File 'sig/resource.rbs', line 104
def composite_alarms: (
|
#metric(namespace, name) ⇒ Metric
116 |
# File 'sig/resource.rbs', line 116
def metric: (String namespace, String name) -> Metric
|