Class: Aws::CloudWatch::Types::AnomalyDetector

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

An anomaly detection model associated with a particular CloudWatch metric, statistic, or metric math expression. You can use the model to display a band of expected, normal values when the metric is graphed.

If you have enabled unified cross-account observability, and this account is a monitoring account, the metric can be in the same account or a source account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::AnomalyDetectorConfiguration

The configuration specifies details about how the anomaly detection model is to be trained, including time ranges to exclude from use for training the model, and the time zone to use for the metric.



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/aws-sdk-cloudwatch/types.rb', line 220

class AnomalyDetector < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :state_value,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#dimensionsArray<Types::Dimension>

The metric dimensions associated with the anomaly detection model.

Returns:



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/aws-sdk-cloudwatch/types.rb', line 220

class AnomalyDetector < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :state_value,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#metric_characteristicsTypes::MetricCharacteristics

This object includes parameters that you can use to provide information about your metric to CloudWatch to help it build more accurate anomaly detection models. Currently, it includes the ‘PeriodicSpikes` parameter.



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/aws-sdk-cloudwatch/types.rb', line 220

class AnomalyDetector < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :state_value,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#metric_math_anomaly_detectorTypes::MetricMathAnomalyDetector

The CloudWatch metric math expression for this anomaly detector.



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/aws-sdk-cloudwatch/types.rb', line 220

class AnomalyDetector < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :state_value,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the metric associated with the anomaly detection model.

Returns:

  • (String)


220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/aws-sdk-cloudwatch/types.rb', line 220

class AnomalyDetector < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :state_value,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace of the metric associated with the anomaly detection model.

Returns:

  • (String)


220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/aws-sdk-cloudwatch/types.rb', line 220

class AnomalyDetector < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :state_value,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#single_metric_anomaly_detectorTypes::SingleMetricAnomalyDetector

The CloudWatch metric and statistic for this anomaly detector.



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/aws-sdk-cloudwatch/types.rb', line 220

class AnomalyDetector < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :state_value,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#statString

The statistic associated with the anomaly detection model.

Returns:

  • (String)


220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/aws-sdk-cloudwatch/types.rb', line 220

class AnomalyDetector < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :state_value,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#state_valueString

The current status of the anomaly detector’s training.

Returns:

  • (String)


220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/aws-sdk-cloudwatch/types.rb', line 220

class AnomalyDetector < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :state_value,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end