Class: Aws::CloudWatch::Types::AssociateDatasetKmsKeyInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::AssociateDatasetKmsKeyInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_identifier ⇒ String
Specifies the identifier of the dataset that you want to associate the KMS key with.
-
#kms_key_arn ⇒ String
Specifies the Amazon Resource Name (ARN) of the customer managed KMS key to associate with the dataset.
Instance Attribute Details
#dataset_identifier ⇒ String
Specifies the identifier of the dataset that you want to associate the KMS key with. For the ‘default` dataset, you can specify either `default` or the full dataset Amazon Resource Name (ARN) in the format `arn:aws:cloudwatch:Region:account-id:dataset/default`.
295 296 297 298 299 300 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 295 class AssociateDatasetKmsKeyInput < Struct.new( :dataset_identifier, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
Specifies the Amazon Resource Name (ARN) of the customer managed KMS key to associate with the dataset. The key must be a symmetric encryption KMS key (‘SYMMETRIC_DEFAULT`) in the same Amazon Web Services Region as the dataset.
The ARN must be in the format ‘arn:aws:kms:Region:account-id:key/key-id `. Key IDs, aliases, and alias ARNs are not accepted.
For more information about KMS key ARNs, see [Key ARN] in the *Amazon Web Services Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id-key-ARN
295 296 297 298 299 300 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 295 class AssociateDatasetKmsKeyInput < Struct.new( :dataset_identifier, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |