Class: Aws::CloudWatch::Types::DashboardEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::DashboardEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Represents a specific dashboard.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dashboard_arn ⇒ String
The Amazon Resource Name (ARN) of the dashboard.
-
#dashboard_name ⇒ String
The name of the dashboard.
-
#last_modified ⇒ Time
The time stamp of when the dashboard was last modified, either by an API call or through the console.
-
#size ⇒ Integer
The size of the dashboard, in bytes.
Instance Attribute Details
#dashboard_arn ⇒ String
The Amazon Resource Name (ARN) of the dashboard.
481 482 483 484 485 486 487 488 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 481 class DashboardEntry < Struct.new( :dashboard_name, :dashboard_arn, :last_modified, :size) SENSITIVE = [] include Aws::Structure end |
#dashboard_name ⇒ String
The name of the dashboard.
481 482 483 484 485 486 487 488 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 481 class DashboardEntry < Struct.new( :dashboard_name, :dashboard_arn, :last_modified, :size) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The time stamp of when the dashboard was last modified, either by an API call or through the console. This number is expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC.
481 482 483 484 485 486 487 488 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 481 class DashboardEntry < Struct.new( :dashboard_name, :dashboard_arn, :last_modified, :size) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
The size of the dashboard, in bytes.
481 482 483 484 485 486 487 488 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 481 class DashboardEntry < Struct.new( :dashboard_name, :dashboard_arn, :last_modified, :size) SENSITIVE = [] include Aws::Structure end |