Class: Aws::CloudWatch::Types::DescribeAlarmHistoryInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_contributor_idString

The unique identifier of a specific alarm contributor to filter the alarm history results.

Returns:

  • (String)


854
855
856
857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854

class DescribeAlarmHistoryInput < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_types,
  :history_item_type,
  :start_date,
  :end_date,
  :max_records,
  :next_token,
  :scan_by)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_nameString

The name of the alarm.

Returns:

  • (String)


854
855
856
857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854

class DescribeAlarmHistoryInput < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_types,
  :history_item_type,
  :start_date,
  :end_date,
  :max_records,
  :next_token,
  :scan_by)
  SENSITIVE = []
  include Aws::Structure
end

#alarm_typesArray<String>

Use this parameter to specify whether you want the operation to return metric alarms, composite alarms, or log alarms. If you omit this parameter, only metric alarms are returned.

Returns:

  • (Array<String>)


854
855
856
857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854

class DescribeAlarmHistoryInput < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_types,
  :history_item_type,
  :start_date,
  :end_date,
  :max_records,
  :next_token,
  :scan_by)
  SENSITIVE = []
  include Aws::Structure
end

#end_dateTime

The ending date to retrieve alarm history.

Returns:

  • (Time)


854
855
856
857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854

class DescribeAlarmHistoryInput < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_types,
  :history_item_type,
  :start_date,
  :end_date,
  :max_records,
  :next_token,
  :scan_by)
  SENSITIVE = []
  include Aws::Structure
end

#history_item_typeString

The type of alarm histories to retrieve.

Returns:

  • (String)


854
855
856
857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854

class DescribeAlarmHistoryInput < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_types,
  :history_item_type,
  :start_date,
  :end_date,
  :max_records,
  :next_token,
  :scan_by)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of alarm history records to retrieve.

Returns:

  • (Integer)


854
855
856
857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854

class DescribeAlarmHistoryInput < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_types,
  :history_item_type,
  :start_date,
  :end_date,
  :max_records,
  :next_token,
  :scan_by)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned by a previous call to indicate that there is more data available.

Returns:

  • (String)


854
855
856
857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854

class DescribeAlarmHistoryInput < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_types,
  :history_item_type,
  :start_date,
  :end_date,
  :max_records,
  :next_token,
  :scan_by)
  SENSITIVE = []
  include Aws::Structure
end

#scan_byString

Specified whether to return the newest or oldest alarm history first. Specify TimestampDescending to have the newest event history returned first, and specify TimestampAscending to have the oldest history returned first.

Returns:

  • (String)


854
855
856
857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854

class DescribeAlarmHistoryInput < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_types,
  :history_item_type,
  :start_date,
  :end_date,
  :max_records,
  :next_token,
  :scan_by)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

The starting date to retrieve alarm history.

Returns:

  • (Time)


854
855
856
857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854

class DescribeAlarmHistoryInput < Struct.new(
  :alarm_name,
  :alarm_contributor_id,
  :alarm_types,
  :history_item_type,
  :start_date,
  :end_date,
  :max_records,
  :next_token,
  :scan_by)
  SENSITIVE = []
  include Aws::Structure
end