Class: Aws::CloudWatch::Types::DescribeAlarmHistoryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::DescribeAlarmHistoryInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_contributor_id ⇒ String
The unique identifier of a specific alarm contributor to filter the alarm history results.
-
#alarm_name ⇒ String
The name of the alarm.
-
#alarm_types ⇒ Array<String>
Use this parameter to specify whether you want the operation to return metric alarms, composite alarms, or log alarms.
-
#end_date ⇒ Time
The ending date to retrieve alarm history.
-
#history_item_type ⇒ String
The type of alarm histories to retrieve.
-
#max_records ⇒ Integer
The maximum number of alarm history records to retrieve.
-
#next_token ⇒ String
The token returned by a previous call to indicate that there is more data available.
-
#scan_by ⇒ String
Specified whether to return the newest or oldest alarm history first.
-
#start_date ⇒ Time
The starting date to retrieve alarm history.
Instance Attribute Details
#alarm_contributor_id ⇒ String
The unique identifier of a specific alarm contributor to filter the alarm history results.
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854 class DescribeAlarmHistoryInput < Struct.new( :alarm_name, :alarm_contributor_id, :alarm_types, :history_item_type, :start_date, :end_date, :max_records, :next_token, :scan_by) SENSITIVE = [] include Aws::Structure end |
#alarm_name ⇒ String
The name of the alarm.
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854 class DescribeAlarmHistoryInput < Struct.new( :alarm_name, :alarm_contributor_id, :alarm_types, :history_item_type, :start_date, :end_date, :max_records, :next_token, :scan_by) SENSITIVE = [] include Aws::Structure end |
#alarm_types ⇒ Array<String>
Use this parameter to specify whether you want the operation to return metric alarms, composite alarms, or log alarms. If you omit this parameter, only metric alarms are returned.
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854 class DescribeAlarmHistoryInput < Struct.new( :alarm_name, :alarm_contributor_id, :alarm_types, :history_item_type, :start_date, :end_date, :max_records, :next_token, :scan_by) SENSITIVE = [] include Aws::Structure end |
#end_date ⇒ Time
The ending date to retrieve alarm history.
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854 class DescribeAlarmHistoryInput < Struct.new( :alarm_name, :alarm_contributor_id, :alarm_types, :history_item_type, :start_date, :end_date, :max_records, :next_token, :scan_by) SENSITIVE = [] include Aws::Structure end |
#history_item_type ⇒ String
The type of alarm histories to retrieve.
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854 class DescribeAlarmHistoryInput < Struct.new( :alarm_name, :alarm_contributor_id, :alarm_types, :history_item_type, :start_date, :end_date, :max_records, :next_token, :scan_by) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of alarm history records to retrieve.
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854 class DescribeAlarmHistoryInput < Struct.new( :alarm_name, :alarm_contributor_id, :alarm_types, :history_item_type, :start_date, :end_date, :max_records, :next_token, :scan_by) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned by a previous call to indicate that there is more data available.
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854 class DescribeAlarmHistoryInput < Struct.new( :alarm_name, :alarm_contributor_id, :alarm_types, :history_item_type, :start_date, :end_date, :max_records, :next_token, :scan_by) SENSITIVE = [] include Aws::Structure end |
#scan_by ⇒ String
Specified whether to return the newest or oldest alarm history
first. Specify TimestampDescending to have the newest event
history returned first, and specify TimestampAscending to have the
oldest history returned first.
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854 class DescribeAlarmHistoryInput < Struct.new( :alarm_name, :alarm_contributor_id, :alarm_types, :history_item_type, :start_date, :end_date, :max_records, :next_token, :scan_by) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The starting date to retrieve alarm history.
854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 854 class DescribeAlarmHistoryInput < Struct.new( :alarm_name, :alarm_contributor_id, :alarm_types, :history_item_type, :start_date, :end_date, :max_records, :next_token, :scan_by) SENSITIVE = [] include Aws::Structure end |