Class: Aws::CloudWatch::Types::DescribeAlarmsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::DescribeAlarmsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_prefix ⇒ String
Use this parameter to filter the results of the operation to only those alarms that use a certain alarm action.
-
#alarm_name_prefix ⇒ String
An alarm name prefix.
-
#alarm_names ⇒ Array<String>
The names of the alarms to retrieve information about.
-
#alarm_types ⇒ Array<String>
Use this parameter to specify whether you want the operation to return metric alarms, composite alarms, or log alarms.
-
#children_of_alarm_name ⇒ String
If you use this parameter and specify the name of a composite alarm, the operation returns information about the "children" alarms of the alarm you specify.
-
#max_records ⇒ Integer
The maximum number of alarm descriptions to retrieve.
-
#next_token ⇒ String
The token returned by a previous call to indicate that there is more data available.
-
#parents_of_alarm_name ⇒ String
If you use this parameter and specify the name of a metric or composite alarm, the operation returns information about the "parent" alarms of the alarm you specify.
-
#state_value ⇒ String
Specify this parameter to receive information only about alarms that are currently in the state that you specify.
Instance Attribute Details
#action_prefix ⇒ String
Use this parameter to filter the results of the operation to only those alarms that use a certain alarm action. For example, you could specify the ARN of an SNS topic to find all alarms that send notifications to that topic.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1023 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#alarm_name_prefix ⇒ String
An alarm name prefix. If you specify this parameter, you receive information about all alarms that have names that start with this prefix.
If this parameter is specified, you cannot specify AlarmNames.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1023 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#alarm_names ⇒ Array<String>
The names of the alarms to retrieve information about.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1023 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#alarm_types ⇒ Array<String>
Use this parameter to specify whether you want the operation to return metric alarms, composite alarms, or log alarms. If you omit this parameter, only metric alarms are returned, even if composite alarms or log alarms exist in the account.
For example, if you omit this parameter or specify MetricAlarms,
the operation returns only a list of metric alarms. It does not
return any composite alarms or log alarms, even if they exist in the
account.
If you specify CompositeAlarms, the operation returns only a list
of composite alarms, and does not return any metric alarms or log
alarms.
If you specify LogAlarms, the operation returns only a list of log
alarms, and does not return any metric alarms or composite alarms.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1023 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#children_of_alarm_name ⇒ String
If you use this parameter and specify the name of a composite alarm,
the operation returns information about the "children" alarms of
the alarm you specify. These are the metric alarms and composite
alarms referenced in the AlarmRule field of the composite alarm
that you specify in ChildrenOfAlarmName. Information about the
composite alarm that you name in ChildrenOfAlarmName is not
returned.
If you specify ChildrenOfAlarmName, you cannot specify any other
parameters in the request except for MaxRecords and NextToken.
If you do so, you receive a validation error.
Alarm Name, ARN, StateValue
(OK/ALARM/INSUFFICIENT_DATA), and StateUpdatedTimestamp
information are returned by this operation when you use this
parameter. To get complete information about these alarms, perform
another DescribeAlarms operation and specify the parent alarm
names in the AlarmNames parameter.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1023 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of alarm descriptions to retrieve.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1023 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned by a previous call to indicate that there is more data available.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1023 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#parents_of_alarm_name ⇒ String
If you use this parameter and specify the name of a metric or
composite alarm, the operation returns information about the
"parent" alarms of the alarm you specify. These are the composite
alarms that have AlarmRule parameters that reference the alarm
named in ParentsOfAlarmName. Information about the alarm that you
specify in ParentsOfAlarmName is not returned.
If you specify ParentsOfAlarmName, you cannot specify any other
parameters in the request except for MaxRecords and NextToken.
If you do so, you receive a validation error.
DescribeAlarms operation and specify the parent
alarm names in the AlarmNames parameter.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1023 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#state_value ⇒ String
Specify this parameter to receive information only about alarms that are currently in the state that you specify.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1023 class DescribeAlarmsInput < Struct.new( :alarm_names, :alarm_name_prefix, :alarm_types, :children_of_alarm_name, :parents_of_alarm_name, :state_value, :action_prefix, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |