Class: Aws::CloudWatch::Types::DescribeAnomalyDetectorsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anomaly_detector_typesArray<String>

The anomaly detector types to request when using ‘DescribeAnomalyDetectorsInput`. If empty, defaults to `SINGLE_METRIC`.

Returns:

  • (Array<String>)


1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1059

class DescribeAnomalyDetectorsInput < Struct.new(
  :next_token,
  :max_results,
  :namespace,
  :metric_name,
  :dimensions,
  :anomaly_detector_types)
  SENSITIVE = []
  include Aws::Structure
end

#dimensionsArray<Types::Dimension>

Limits the results to only the anomaly detection models that are associated with the specified metric dimensions. If there are multiple metrics that have these dimensions and have anomaly detection models associated, they’re all returned.

Returns:



1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1059

class DescribeAnomalyDetectorsInput < Struct.new(
  :next_token,
  :max_results,
  :namespace,
  :metric_name,
  :dimensions,
  :anomaly_detector_types)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in one operation. The maximum value that you can specify is 100.

To retrieve the remaining results, make another call with the returned ‘NextToken` value.

Returns:

  • (Integer)


1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1059

class DescribeAnomalyDetectorsInput < Struct.new(
  :next_token,
  :max_results,
  :namespace,
  :metric_name,
  :dimensions,
  :anomaly_detector_types)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

Limits the results to only the anomaly detection models that are associated with the specified metric name. If there are multiple metrics with this name in different namespaces that have anomaly detection models, they’re all returned.

Returns:

  • (String)


1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1059

class DescribeAnomalyDetectorsInput < Struct.new(
  :next_token,
  :max_results,
  :namespace,
  :metric_name,
  :dimensions,
  :anomaly_detector_types)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

Limits the results to only the anomaly detection models that are associated with the specified namespace.

Returns:

  • (String)


1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1059

class DescribeAnomalyDetectorsInput < Struct.new(
  :next_token,
  :max_results,
  :namespace,
  :metric_name,
  :dimensions,
  :anomaly_detector_types)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Use the token returned by the previous operation to request the next page of results.

Returns:

  • (String)


1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1059

class DescribeAnomalyDetectorsInput < Struct.new(
  :next_token,
  :max_results,
  :namespace,
  :metric_name,
  :dimensions,
  :anomaly_detector_types)
  SENSITIVE = []
  include Aws::Structure
end