Method: Aws::CloudWatch::Types::Dimension#name
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
#name ⇒ String
The name of the dimension. Dimension names must contain only ASCII characters, must include at least one non-whitespace character, and cannot start with a colon (:). ASCII control characters are not supported as part of dimension names.
1120 1121 1122 1123 1124 1125 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1120 class Dimension < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |