Class: Aws::CloudWatch::Types::DisassociateDatasetKmsKeyInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::DisassociateDatasetKmsKeyInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_identifier ⇒ String
Specifies the identifier of the dataset from which to remove the KMS key association.
Instance Attribute Details
#dataset_identifier ⇒ String
Specifies the identifier of the dataset from which to remove the KMS key association. For the ‘default` dataset, you can specify either `default` or the full dataset Amazon Resource Name (ARN) in the format `arn:aws:cloudwatch:Region:account-id:dataset/default`.
1265 1266 1267 1268 1269 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1265 class DisassociateDatasetKmsKeyInput < Struct.new( :dataset_identifier) SENSITIVE = [] include Aws::Structure end |