Class: Aws::CloudWatch::Types::EvaluationWindow
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::EvaluationWindow
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
EvaluationWindow is a union - when making an API calls you must set exactly one of the members.
EvaluationWindow is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EvaluationWindow corresponding to the set member.
The evaluation window that an alarm uses to select the range of metric
data that it evaluates each time it runs. This is a union type. Set
exactly one of its members, SlidingWindow or WallClockWindow. If
you don't set EvaluationWindow, the alarm uses a SlidingWindow by
default.
For more information, see Alarm evaluation windows in the CloudWatch User Guide.
Defined Under Namespace
Classes: SlidingWindow, Unknown, WallClockWindow
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#sliding_window ⇒ Types::SlidingWindow
A sliding window, which advances each time the alarm is evaluated, forming a rolling time window.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#wall_clock_window ⇒ Types::WallClockWindow
A wall clock window, which aligns the evaluated range to fixed clock boundaries that match the alarm's period, such as the top of the hour, midnight, or the start of the calendar week.
Instance Attribute Details
#sliding_window ⇒ Types::SlidingWindow
A sliding window, which advances each time the alarm is evaluated, forming a rolling time window. This is the default evaluation window.
1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1474 class EvaluationWindow < Struct.new( :wall_clock_window, :sliding_window, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class WallClockWindow < EvaluationWindow; end class SlidingWindow < EvaluationWindow; end class Unknown < EvaluationWindow; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1474 1475 1476 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1474 def unknown @unknown end |
#wall_clock_window ⇒ Types::WallClockWindow
A wall clock window, which aligns the evaluated range to fixed clock boundaries that match the alarm's period, such as the top of the hour, midnight, or the start of the calendar week.
1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1474 class EvaluationWindow < Struct.new( :wall_clock_window, :sliding_window, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class WallClockWindow < EvaluationWindow; end class SlidingWindow < EvaluationWindow; end class Unknown < EvaluationWindow; end end |