Class: Aws::CloudWatch::Types::GetAlarmMuteRuleOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::GetAlarmMuteRuleOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_mute_rule_arn ⇒ String
The Amazon Resource Name (ARN) of the alarm mute rule.
-
#description ⇒ String
The description of the alarm mute rule.
-
#expire_date ⇒ Time
The date and time when the mute rule expires and is no longer evaluated.
-
#last_updated_timestamp ⇒ Time
The date and time when the mute rule was last updated.
-
#mute_targets ⇒ Types::MuteTargets
Specifies which alarms this rule applies to.
-
#mute_type ⇒ String
Indicates whether the mute rule is one-time or recurring.
-
#name ⇒ String
The name of the alarm mute rule.
-
#rule ⇒ Types::Rule
The configuration that defines when and how long alarms are muted.
-
#start_date ⇒ Time
The date and time when the mute rule becomes active.
-
#status ⇒ String
The current status of the alarm mute rule.
Instance Attribute Details
#alarm_mute_rule_arn ⇒ String
The Amazon Resource Name (ARN) of the alarm mute rule.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the alarm mute rule.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |
#expire_date ⇒ Time
The date and time when the mute rule expires and is no longer evaluated.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |
#last_updated_timestamp ⇒ Time
The date and time when the mute rule was last updated.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |
#mute_targets ⇒ Types::MuteTargets
Specifies which alarms this rule applies to.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |
#mute_type ⇒ String
Indicates whether the mute rule is one-time or recurring. Valid values are ‘ONE_TIME` or `RECURRING`.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the alarm mute rule.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |
#rule ⇒ Types::Rule
The configuration that defines when and how long alarms are muted.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The date and time when the mute rule becomes active. If not set, the rule is active immediately.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the alarm mute rule. Valid values are ‘SCHEDULED`, `ACTIVE`, or `EXPIRED`.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1466 class GetAlarmMuteRuleOutput < Struct.new( :name, :alarm_mute_rule_arn, :description, :rule, :mute_targets, :start_date, :expire_date, :status, :last_updated_timestamp, :mute_type) SENSITIVE = [] include Aws::Structure end |