Class: Aws::CloudWatch::Types::GetDashboardOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::GetDashboardOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dashboard_arn ⇒ String
The Amazon Resource Name (ARN) of the dashboard.
-
#dashboard_body ⇒ String
The detailed information about the dashboard, including what widgets are included and their location on the dashboard.
-
#dashboard_name ⇒ String
The name of the dashboard.
Instance Attribute Details
#dashboard_arn ⇒ String
The Amazon Resource Name (ARN) of the dashboard.
1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1567 class GetDashboardOutput < Struct.new( :dashboard_arn, :dashboard_body, :dashboard_name) SENSITIVE = [] include Aws::Structure end |
#dashboard_body ⇒ String
The detailed information about the dashboard, including what widgets
are included and their location on the dashboard. For more
information about the DashboardBody syntax, see Dashboard Body
Structure and Syntax.
1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1567 class GetDashboardOutput < Struct.new( :dashboard_arn, :dashboard_body, :dashboard_name) SENSITIVE = [] include Aws::Structure end |
#dashboard_name ⇒ String
The name of the dashboard.
1567 1568 1569 1570 1571 1572 1573 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1567 class GetDashboardOutput < Struct.new( :dashboard_arn, :dashboard_body, :dashboard_name) SENSITIVE = [] include Aws::Structure end |