Class: Aws::CloudWatch::Types::GetDatasetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::GetDatasetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Returns the Amazon Resource Name (ARN) of the dataset, in the format ‘arn:aws:cloudwatch:Region:account-id:dataset/dataset-id `.
-
#dataset_id ⇒ String
Returns the identifier of the dataset.
-
#kms_key_arn ⇒ String
Returns the Amazon Resource Name (ARN) of the customer managed Amazon Web Services KMS key that is currently associated with the dataset, if any.
Instance Attribute Details
#arn ⇒ String
Returns the Amazon Resource Name (ARN) of the dataset, in the format ‘arn:aws:cloudwatch:Region:account-id:dataset/dataset-id `.
1556 1557 1558 1559 1560 1561 1562 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1556 class GetDatasetOutput < Struct.new( :dataset_id, :arn, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#dataset_id ⇒ String
Returns the identifier of the dataset.
1556 1557 1558 1559 1560 1561 1562 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1556 class GetDatasetOutput < Struct.new( :dataset_id, :arn, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
Returns the Amazon Resource Name (ARN) of the customer managed Amazon Web Services KMS key that is currently associated with the dataset, if any. If the dataset is not associated with a customer managed KMS key, this field is not included in the response and the dataset is encrypted at rest using an Amazon Web Services owned key.
1556 1557 1558 1559 1560 1561 1562 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 1556 class GetDatasetOutput < Struct.new( :dataset_id, :arn, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |