Class: Aws::CloudWatch::Types::InsightRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::InsightRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
This structure contains the definition for a Contributor Insights rule. For more information about this rule, see Using Constributor Insights to analyze high-cardinality data in the Amazon CloudWatch User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_on_transformed_logs ⇒ Boolean
Displays whether the rule is evaluated on the transformed versions of logs, for log groups that have [Log transformation][1] enabled.
-
#definition ⇒ String
The definition of the rule, as a JSON object.
-
#managed_rule ⇒ Boolean
An optional built-in rule that Amazon Web Services manages.
-
#name ⇒ String
The name of the rule.
-
#schema ⇒ String
For rules that you create, this is always
{"Name": "CloudWatchLogRule", "Version": 1}. -
#state ⇒ String
Indicates whether the rule is enabled or disabled.
Instance Attribute Details
#apply_on_transformed_logs ⇒ Boolean
Displays whether the rule is evaluated on the transformed versions
of logs, for log groups that have Log transformation enabled.
If this is false, log events are evaluated before they are
transformed.
2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2223 class InsightRule < Struct.new( :name, :state, :schema, :definition, :managed_rule, :apply_on_transformed_logs) SENSITIVE = [] include Aws::Structure end |
#definition ⇒ String
The definition of the rule, as a JSON object. The definition contains the keywords used to define contributors, the value to aggregate on if this rule returns a sum instead of a count, and the filters. For details on the valid syntax, see Contributor Insights Rule Syntax.
2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2223 class InsightRule < Struct.new( :name, :state, :schema, :definition, :managed_rule, :apply_on_transformed_logs) SENSITIVE = [] include Aws::Structure end |
#managed_rule ⇒ Boolean
An optional built-in rule that Amazon Web Services manages.
2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2223 class InsightRule < Struct.new( :name, :state, :schema, :definition, :managed_rule, :apply_on_transformed_logs) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule.
2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2223 class InsightRule < Struct.new( :name, :state, :schema, :definition, :managed_rule, :apply_on_transformed_logs) SENSITIVE = [] include Aws::Structure end |
#schema ⇒ String
For rules that you create, this is always {"Name": "CloudWatchLogRule", "Version": 1}. For managed rules, this is
{"Name": "ServiceLogRule", "Version": 1}
2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2223 class InsightRule < Struct.new( :name, :state, :schema, :definition, :managed_rule, :apply_on_transformed_logs) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Indicates whether the rule is enabled or disabled.
2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2223 class InsightRule < Struct.new( :name, :state, :schema, :definition, :managed_rule, :apply_on_transformed_logs) SENSITIVE = [] include Aws::Structure end |