Class: Aws::CloudWatch::Types::KmsAccessDeniedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::KmsAccessDeniedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
The operation was denied because either the calling principal lacks
the required Amazon Web Services Key Management Service (Amazon Web
Services KMS) permission on the key, or the key policy does not grant
Amazon CloudWatch the permissions it needs to use the key. Verify that
the caller has kms:Decrypt permission on the key, and that the key
policy grants the CloudWatch service principal the kms:DescribeKey,
kms:GenerateDataKey, kms:Encrypt, kms:Decrypt, and
kms:ReEncrypt* permissions described in AssociateDatasetKmsKey.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
2470 2471 2472 2473 2474 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2470 class KmsAccessDeniedException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |