Class: Aws::CloudWatch::Types::KmsKeyNotFoundException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

The specified Amazon Web Services Key Management Service (Amazon Web Services KMS) key could not be found. Verify that the key Amazon Resource Name (ARN) is correct, that the key exists, and that it is in the same Amazon Web Services Region as the resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2501
2502
2503
2504
2505
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2501

class KmsKeyNotFoundException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end