Class: Aws::CloudWatch::Types::ListMetricsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dimensionsArray<Types::DimensionFilter>

The dimensions to filter against. Only the dimension with names that match exactly will be returned. If you specify one dimension name and a metric has that dimension and also other dimensions, it will be returned.

Returns:



2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537

class ListMetricsInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :next_token,
  :recently_active,
  :include_linked_accounts,
  :owning_account)
  SENSITIVE = []
  include Aws::Structure
end

#include_linked_accountsBoolean

If you are using this operation in a monitoring account, specify true to include metrics from source accounts in the returned data.

The default is false.

Returns:

  • (Boolean)


2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537

class ListMetricsInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :next_token,
  :recently_active,
  :include_linked_accounts,
  :owning_account)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the metric to filter against. Only the metrics with names that match exactly will be returned.

Returns:

  • (String)


2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537

class ListMetricsInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :next_token,
  :recently_active,
  :include_linked_accounts,
  :owning_account)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The metric namespace to filter against. Only the namespace that matches exactly will be returned.

Returns:

  • (String)


2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537

class ListMetricsInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :next_token,
  :recently_active,
  :include_linked_accounts,
  :owning_account)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned by a previous call to indicate that there is more data available.

Returns:

  • (String)


2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537

class ListMetricsInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :next_token,
  :recently_active,
  :include_linked_accounts,
  :owning_account)
  SENSITIVE = []
  include Aws::Structure
end

#owning_accountString

When you use this operation in a monitoring account, use this field to return metrics only from one source account. To do so, specify that source account ID in this field, and also specify true for IncludeLinkedAccounts.

Returns:

  • (String)


2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537

class ListMetricsInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :next_token,
  :recently_active,
  :include_linked_accounts,
  :owning_account)
  SENSITIVE = []
  include Aws::Structure
end

#recently_activeString

To filter the results to show only metrics that have had data points published in the past three hours, specify this parameter with a value of PT3H. This is the only valid value for this parameter.

The results that are returned are an approximation of the value you specify. There is a low probability that the returned results include metrics with last published data as much as 50 minutes more than the specified time interval.

Returns:

  • (String)


2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537

class ListMetricsInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :next_token,
  :recently_active,
  :include_linked_accounts,
  :owning_account)
  SENSITIVE = []
  include Aws::Structure
end