Class: Aws::CloudWatch::Types::ListMetricsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::ListMetricsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<Types::DimensionFilter>
The dimensions to filter against.
-
#include_linked_accounts ⇒ Boolean
If you are using this operation in a monitoring account, specify
trueto include metrics from source accounts in the returned data. -
#metric_name ⇒ String
The name of the metric to filter against.
-
#namespace ⇒ String
The metric namespace to filter against.
-
#next_token ⇒ String
The token returned by a previous call to indicate that there is more data available.
-
#owning_account ⇒ String
When you use this operation in a monitoring account, use this field to return metrics only from one source account.
-
#recently_active ⇒ String
To filter the results to show only metrics that have had data points published in the past three hours, specify this parameter with a value of
PT3H.
Instance Attribute Details
#dimensions ⇒ Array<Types::DimensionFilter>
The dimensions to filter against. Only the dimension with names that match exactly will be returned. If you specify one dimension name and a metric has that dimension and also other dimensions, it will be returned.
2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537 class ListMetricsInput < Struct.new( :namespace, :metric_name, :dimensions, :next_token, :recently_active, :include_linked_accounts, :owning_account) SENSITIVE = [] include Aws::Structure end |
#include_linked_accounts ⇒ Boolean
If you are using this operation in a monitoring account, specify true to include metrics from source accounts in the returned data.
The default is false.
2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537 class ListMetricsInput < Struct.new( :namespace, :metric_name, :dimensions, :next_token, :recently_active, :include_linked_accounts, :owning_account) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric to filter against. Only the metrics with names that match exactly will be returned.
2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537 class ListMetricsInput < Struct.new( :namespace, :metric_name, :dimensions, :next_token, :recently_active, :include_linked_accounts, :owning_account) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The metric namespace to filter against. Only the namespace that matches exactly will be returned.
2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537 class ListMetricsInput < Struct.new( :namespace, :metric_name, :dimensions, :next_token, :recently_active, :include_linked_accounts, :owning_account) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned by a previous call to indicate that there is more data available.
2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537 class ListMetricsInput < Struct.new( :namespace, :metric_name, :dimensions, :next_token, :recently_active, :include_linked_accounts, :owning_account) SENSITIVE = [] include Aws::Structure end |
#owning_account ⇒ String
When you use this operation in a monitoring account, use this field to return metrics only from one source account. To do so, specify that source account ID in this field, and also specify true for IncludeLinkedAccounts.
2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537 class ListMetricsInput < Struct.new( :namespace, :metric_name, :dimensions, :next_token, :recently_active, :include_linked_accounts, :owning_account) SENSITIVE = [] include Aws::Structure end |
#recently_active ⇒ String
To filter the results to show only metrics that have had data points published in the past three hours, specify this parameter with a value of PT3H. This is the only valid value for this parameter.
The results that are returned are an approximation of the value you specify. There is a low probability that the returned results include metrics with last published data as much as 50 minutes more than the specified time interval.
2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2537 class ListMetricsInput < Struct.new( :namespace, :metric_name, :dimensions, :next_token, :recently_active, :include_linked_accounts, :owning_account) SENSITIVE = [] include Aws::Structure end |