Class: Aws::CloudWatch::Types::LogAlarm
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::LogAlarm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
The details about a log alarm.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_log_line_count ⇒ Integer
The number of log lines from the most recent scheduled query execution that are included in alarm action notifications.
-
#action_log_line_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that CloudWatch assumes to retrieve log events for inclusion in alarm action notifications.
-
#actions_enabled ⇒ Boolean
Indicates whether actions should be executed during any changes to the alarm state.
-
#alarm_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the
ALARMstate from any other state. -
#alarm_arn ⇒ String
The Amazon Resource Name (ARN) of the alarm.
-
#alarm_configuration_updated_timestamp ⇒ Time
The time stamp of the last update to the alarm configuration.
-
#alarm_description ⇒ String
The description of the alarm.
-
#alarm_name ⇒ String
The name of the alarm.
-
#comparison_operator ⇒ String
The arithmetic operation to use when comparing the aggregated query result and the threshold.
-
#evaluation_state ⇒ String
If the value of this field is
EVALUATION_ERROR, it indicates configuration errors in the alarm setup that require review and correction. -
#insufficient_data_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the
INSUFFICIENT_DATAstate from any other state. -
#ok_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the
OKstate from any other state. -
#query_results_to_alarm ⇒ Integer
The number of query results, out of the most recent
QueryResultsToEvaluateresults, that must breach the threshold to trigger the alarm to transition toALARM(the M in M-of-N evaluation). -
#query_results_to_evaluate ⇒ Integer
The number of most recent scheduled query results that the alarm evaluates against the threshold (the N in M-of-N evaluation).
-
#scheduled_query_configuration ⇒ Types::ScheduledQueryConfiguration
The configuration of the underlying CloudWatch Logs scheduled query, including the query string, log groups, schedule, aggregation expression, and the ARN of the managed scheduled query.
-
#state_reason ⇒ String
An explanation for the alarm state, in text format.
-
#state_reason_data ⇒ String
An explanation for the alarm state, in JSON format.
-
#state_transitioned_timestamp ⇒ Time
The date and time that the alarm's
StateValuemost recently changed. -
#state_updated_timestamp ⇒ Time
The time stamp of the last update to the value of either the
StateValueorEvaluationStateparameters. -
#state_value ⇒ String
The state value for the alarm.
-
#threshold ⇒ Float
The value to compare with the aggregated query result.
-
#treat_missing_data ⇒ String
How this alarm handles missing data points.
Instance Attribute Details
#action_log_line_count ⇒ Integer
The number of log lines from the most recent scheduled query execution that are included in alarm action notifications. Valid range is 0 through 50. A value of 0 means no log lines are included.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#action_log_line_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that CloudWatch
assumes to retrieve log events for inclusion in alarm action
notifications. Set when ActionLogLineCount is greater than 0.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#actions_enabled ⇒ Boolean
Indicates whether actions should be executed during any changes to the alarm state.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#alarm_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the ALARM
state from any other state. Each action is specified as an Amazon
Resource Name (ARN).
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#alarm_arn ⇒ String
The Amazon Resource Name (ARN) of the alarm.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#alarm_configuration_updated_timestamp ⇒ Time
The time stamp of the last update to the alarm configuration.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#alarm_description ⇒ String
The description of the alarm.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#alarm_name ⇒ String
The name of the alarm.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#comparison_operator ⇒ String
The arithmetic operation to use when comparing the aggregated query result and the threshold. The aggregated query result is used as the first operand.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#evaluation_state ⇒ String
If the value of this field is EVALUATION_ERROR, it indicates
configuration errors in the alarm setup that require review and
correction. Refer to the StateReason field of the alarm for more
details.
If the value of this field is EVALUATION_FAILURE, it indicates
temporary CloudWatch issues. We recommend manual monitoring until
the issue is resolved.
If the value of this field is PARTIAL_DATA, it indicates that the
query returned the maximum 500 contributor groups but more matched.
The alarm evaluates the available contributors, but results might be
incomplete.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#insufficient_data_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the
INSUFFICIENT_DATA state from any other state. Each action is
specified as an Amazon Resource Name (ARN).
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#ok_actions ⇒ Array<String>
The actions to execute when this alarm transitions to the OK state
from any other state. Each action is specified as an Amazon Resource
Name (ARN).
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#query_results_to_alarm ⇒ Integer
The number of query results, out of the most recent
QueryResultsToEvaluate results, that must breach the threshold to
trigger the alarm to transition to ALARM (the M in M-of-N
evaluation).
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#query_results_to_evaluate ⇒ Integer
The number of most recent scheduled query results that the alarm evaluates against the threshold (the N in M-of-N evaluation).
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#scheduled_query_configuration ⇒ Types::ScheduledQueryConfiguration
The configuration of the underlying CloudWatch Logs scheduled query, including the query string, log groups, schedule, aggregation expression, and the ARN of the managed scheduled query.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
An explanation for the alarm state, in text format.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#state_reason_data ⇒ String
An explanation for the alarm state, in JSON format.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#state_transitioned_timestamp ⇒ Time
The date and time that the alarm's StateValue most recently
changed.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#state_updated_timestamp ⇒ Time
The time stamp of the last update to the value of either the
StateValue or EvaluationState parameters.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#state_value ⇒ String
The state value for the alarm.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
The value to compare with the aggregated query result.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |
#treat_missing_data ⇒ String
How this alarm handles missing data points. Valid values are
breaching, notBreaching, ignore, and missing.
2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 2987 class LogAlarm < Struct.new( :alarm_name, :alarm_arn, :alarm_description, :alarm_configuration_updated_timestamp, :actions_enabled, :ok_actions, :alarm_actions, :insufficient_data_actions, :state_value, :state_reason, :state_reason_data, :state_updated_timestamp, :scheduled_query_configuration, :query_results_to_evaluate, :query_results_to_alarm, :threshold, :comparison_operator, :treat_missing_data, :state_transitioned_timestamp, :evaluation_state, :action_log_line_count, :action_log_line_role_arn) SENSITIVE = [] include Aws::Structure end |