Class: Aws::CloudWatch::Types::PartialFailure
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::PartialFailure
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
This array is empty if the API operation was successful for all the rules specified in the request. If the operation could not process one of the rules, the following data is returned for each of those rules.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exception_type ⇒ String
The type of error.
-
#failure_code ⇒ String
The code of the error.
-
#failure_description ⇒ String
A description of the error.
-
#failure_resource ⇒ String
The specified rule that could not be deleted.
Instance Attribute Details
#exception_type ⇒ String
The type of error.
3815 3816 3817 3818 3819 3820 3821 3822 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3815 class PartialFailure < Struct.new( :failure_resource, :exception_type, :failure_code, :failure_description) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
The code of the error.
3815 3816 3817 3818 3819 3820 3821 3822 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3815 class PartialFailure < Struct.new( :failure_resource, :exception_type, :failure_code, :failure_description) SENSITIVE = [] include Aws::Structure end |
#failure_description ⇒ String
A description of the error.
3815 3816 3817 3818 3819 3820 3821 3822 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3815 class PartialFailure < Struct.new( :failure_resource, :exception_type, :failure_code, :failure_description) SENSITIVE = [] include Aws::Structure end |
#failure_resource ⇒ String
The specified rule that could not be deleted.
3815 3816 3817 3818 3819 3820 3821 3822 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3815 class PartialFailure < Struct.new( :failure_resource, :exception_type, :failure_code, :failure_description) SENSITIVE = [] include Aws::Structure end |