Class: Aws::CloudWatch::Types::PartialFailure

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

This array is empty if the API operation was successful for all the rules specified in the request. If the operation could not process one of the rules, the following data is returned for each of those rules.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#exception_typeString

The type of error.

Returns:

  • (String)


3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3661

class PartialFailure < Struct.new(
  :failure_resource,
  :exception_type,
  :failure_code,
  :failure_description)
  SENSITIVE = []
  include Aws::Structure
end

#failure_codeString

The code of the error.

Returns:

  • (String)


3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3661

class PartialFailure < Struct.new(
  :failure_resource,
  :exception_type,
  :failure_code,
  :failure_description)
  SENSITIVE = []
  include Aws::Structure
end

#failure_descriptionString

A description of the error.

Returns:

  • (String)


3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3661

class PartialFailure < Struct.new(
  :failure_resource,
  :exception_type,
  :failure_code,
  :failure_description)
  SENSITIVE = []
  include Aws::Structure
end

#failure_resourceString

The specified rule that could not be deleted.

Returns:

  • (String)


3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3661

class PartialFailure < Struct.new(
  :failure_resource,
  :exception_type,
  :failure_code,
  :failure_description)
  SENSITIVE = []
  include Aws::Structure
end