Class: Aws::CloudWatch::Types::PutAlarmMuteRuleInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::PutAlarmMuteRuleInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the alarm mute rule that helps you identify its purpose.
-
#expire_date ⇒ Time
The date and time when the mute rule expires and is no longer evaluated, specified as a timestamp in ISO 8601 format (for example, ‘2026-12-31T23:59:59Z`).
-
#mute_targets ⇒ Types::MuteTargets
Specifies which alarms this rule applies to.
-
#name ⇒ String
The name of the alarm mute rule.
-
#rule ⇒ Types::Rule
The configuration that defines when and how long alarms should be muted.
-
#start_date ⇒ Time
The date and time after which the mute rule takes effect, specified as a timestamp in ISO 8601 format (for example, ‘2026-04-15T08:00:00Z`).
-
#tags ⇒ Array<Types::Tag>
A list of key-value pairs to associate with the alarm mute rule.
Instance Attribute Details
#description ⇒ String
A description of the alarm mute rule that helps you identify its purpose.
3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3704 class PutAlarmMuteRuleInput < Struct.new( :name, :description, :rule, :mute_targets, :tags, :start_date, :expire_date) SENSITIVE = [] include Aws::Structure end |
#expire_date ⇒ Time
The date and time when the mute rule expires and is no longer evaluated, specified as a timestamp in ISO 8601 format (for example, ‘2026-12-31T23:59:59Z`). After this time, the rule status becomes EXPIRED and will no longer mute the targeted alarms.
3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3704 class PutAlarmMuteRuleInput < Struct.new( :name, :description, :rule, :mute_targets, :tags, :start_date, :expire_date) SENSITIVE = [] include Aws::Structure end |
#mute_targets ⇒ Types::MuteTargets
Specifies which alarms this rule applies to.
3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3704 class PutAlarmMuteRuleInput < Struct.new( :name, :description, :rule, :mute_targets, :tags, :start_date, :expire_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the alarm mute rule. This name must be unique within your Amazon Web Services account and region.
3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3704 class PutAlarmMuteRuleInput < Struct.new( :name, :description, :rule, :mute_targets, :tags, :start_date, :expire_date) SENSITIVE = [] include Aws::Structure end |
#rule ⇒ Types::Rule
The configuration that defines when and how long alarms should be muted.
3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3704 class PutAlarmMuteRuleInput < Struct.new( :name, :description, :rule, :mute_targets, :tags, :start_date, :expire_date) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The date and time after which the mute rule takes effect, specified as a timestamp in ISO 8601 format (for example, ‘2026-04-15T08:00:00Z`). If not specified, the mute rule takes effect immediately upon creation and the mutes are applied as per the schedule expression.
3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3704 class PutAlarmMuteRuleInput < Struct.new( :name, :description, :rule, :mute_targets, :tags, :start_date, :expire_date) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of key-value pairs to associate with the alarm mute rule. You can use tags to categorize and manage your mute rules.
3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 3704 class PutAlarmMuteRuleInput < Struct.new( :name, :description, :rule, :mute_targets, :tags, :start_date, :expire_date) SENSITIVE = [] include Aws::Structure end |