Class: Aws::CloudWatch::Types::PutAnomalyDetectorInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::AnomalyDetectorConfiguration

The configuration specifies details about how the anomaly detection model is to be trained, including time ranges to exclude when training and updating the model. You can specify as many as 10 time ranges.

The configuration can also include the time zone to use for the metric.



4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4199

class PutAnomalyDetectorInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#dimensionsArray<Types::Dimension>

The metric dimensions to create the anomaly detection model for.

Returns:



4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4199

class PutAnomalyDetectorInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#metric_characteristicsTypes::MetricCharacteristics

Use this object to include parameters to provide information about your metric to CloudWatch to help it build more accurate anomaly detection models. Currently, it includes the PeriodicSpikes parameter.



4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4199

class PutAnomalyDetectorInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#metric_math_anomaly_detectorTypes::MetricMathAnomalyDetector

The metric math anomaly detector to be created.

When using MetricMathAnomalyDetector, you cannot include the following parameters in the same operation:

  • Dimensions

  • MetricName

  • Namespace

  • Stat

  • the SingleMetricAnomalyDetector parameters of PutAnomalyDetectorInput

Instead, specify the metric math anomaly detector attributes as part of the property MetricMathAnomalyDetector.



4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4199

class PutAnomalyDetectorInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the metric to create the anomaly detection model for.

Returns:

  • (String)


4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4199

class PutAnomalyDetectorInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace of the metric to create the anomaly detection model for.

Returns:

  • (String)


4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4199

class PutAnomalyDetectorInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#single_metric_anomaly_detectorTypes::SingleMetricAnomalyDetector

A single metric anomaly detector to be created.

When using SingleMetricAnomalyDetector, you cannot include the following parameters in the same operation:

  • Dimensions

  • MetricName

  • Namespace

  • Stat

  • the MetricMathAnomalyDetector parameters of PutAnomalyDetectorInput

Instead, specify the single metric anomaly detector attributes as part of the property SingleMetricAnomalyDetector.



4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4199

class PutAnomalyDetectorInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end

#statString

The statistic to use for the metric and the anomaly detection model.

Returns:

  • (String)


4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
# File 'lib/aws-sdk-cloudwatch/types.rb', line 4199

class PutAnomalyDetectorInput < Struct.new(
  :namespace,
  :metric_name,
  :dimensions,
  :stat,
  :configuration,
  :metric_characteristics,
  :single_metric_anomaly_detector,
  :metric_math_anomaly_detector)
  SENSITIVE = []
  include Aws::Structure
end