Class: Aws::CloudWatch::Types::SingleMetricAnomalyDetector
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::SingleMetricAnomalyDetector
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Designates the CloudWatch metric and statistic that provides the time series the anomaly detector uses as input. If you have enabled unified cross-account observability, and this account is a monitoring account, the metric can be in the same account or a source account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
If the CloudWatch metric that provides the time series that the anomaly detector uses as input is in another account, specify that account ID here.
-
#dimensions ⇒ Array<Types::Dimension>
The metric dimensions to create the anomaly detection model for.
-
#metric_name ⇒ String
The name of the metric to create the anomaly detection model for.
-
#namespace ⇒ String
The namespace of the metric to create the anomaly detection model for.
-
#stat ⇒ String
The statistic to use for the metric and anomaly detection model.
Instance Attribute Details
#account_id ⇒ String
If the CloudWatch metric that provides the time series that the anomaly detector uses as input is in another account, specify that account ID here. If you omit this parameter, the current account is used.
5766 5767 5768 5769 5770 5771 5772 5773 5774 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5766 class SingleMetricAnomalyDetector < Struct.new( :account_id, :namespace, :metric_name, :dimensions, :stat) SENSITIVE = [] include Aws::Structure end |
#dimensions ⇒ Array<Types::Dimension>
The metric dimensions to create the anomaly detection model for.
5766 5767 5768 5769 5770 5771 5772 5773 5774 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5766 class SingleMetricAnomalyDetector < Struct.new( :account_id, :namespace, :metric_name, :dimensions, :stat) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric to create the anomaly detection model for.
5766 5767 5768 5769 5770 5771 5772 5773 5774 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5766 class SingleMetricAnomalyDetector < Struct.new( :account_id, :namespace, :metric_name, :dimensions, :stat) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the metric to create the anomaly detection model for.
5766 5767 5768 5769 5770 5771 5772 5773 5774 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5766 class SingleMetricAnomalyDetector < Struct.new( :account_id, :namespace, :metric_name, :dimensions, :stat) SENSITIVE = [] include Aws::Structure end |
#stat ⇒ String
The statistic to use for the metric and anomaly detection model.
5766 5767 5768 5769 5770 5771 5772 5773 5774 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5766 class SingleMetricAnomalyDetector < Struct.new( :account_id, :namespace, :metric_name, :dimensions, :stat) SENSITIVE = [] include Aws::Structure end |