Class: Aws::CloudWatch::Types::SingleMetricAnomalyDetector

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Designates the CloudWatch metric and statistic that provides the time series the anomaly detector uses as input. If you have enabled unified cross-account observability, and this account is a monitoring account, the metric can be in the same account or a source account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

If the CloudWatch metric that provides the time series that the anomaly detector uses as input is in another account, specify that account ID here. If you omit this parameter, the current account is used.

Returns:

  • (String)


5176
5177
5178
5179
5180
5181
5182
5183
5184
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5176

class SingleMetricAnomalyDetector < Struct.new(
  :account_id,
  :namespace,
  :metric_name,
  :dimensions,
  :stat)
  SENSITIVE = []
  include Aws::Structure
end

#dimensionsArray<Types::Dimension>

The metric dimensions to create the anomaly detection model for.

Returns:



5176
5177
5178
5179
5180
5181
5182
5183
5184
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5176

class SingleMetricAnomalyDetector < Struct.new(
  :account_id,
  :namespace,
  :metric_name,
  :dimensions,
  :stat)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the metric to create the anomaly detection model for.

Returns:

  • (String)


5176
5177
5178
5179
5180
5181
5182
5183
5184
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5176

class SingleMetricAnomalyDetector < Struct.new(
  :account_id,
  :namespace,
  :metric_name,
  :dimensions,
  :stat)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace of the metric to create the anomaly detection model for.

Returns:

  • (String)


5176
5177
5178
5179
5180
5181
5182
5183
5184
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5176

class SingleMetricAnomalyDetector < Struct.new(
  :account_id,
  :namespace,
  :metric_name,
  :dimensions,
  :stat)
  SENSITIVE = []
  include Aws::Structure
end

#statString

The statistic to use for the metric and anomaly detection model.

Returns:

  • (String)


5176
5177
5178
5179
5180
5181
5182
5183
5184
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5176

class SingleMetricAnomalyDetector < Struct.new(
  :account_id,
  :namespace,
  :metric_name,
  :dimensions,
  :stat)
  SENSITIVE = []
  include Aws::Structure
end