Class: Aws::CloudWatch::Types::StartMetricStreamsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::StartMetricStreamsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#names ⇒ Array<String>
The array of the names of metric streams to start streaming.
Instance Attribute Details
#names ⇒ Array<String>
The array of the names of metric streams to start streaming.
This is an "all or nothing" operation. If you do not have permission to access all of the metric streams that you list here, then none of the streams that you list in the operation will start streaming.
5975 5976 5977 5978 5979 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5975 class StartMetricStreamsInput < Struct.new( :names) SENSITIVE = [] include Aws::Structure end |