Class: Aws::CloudWatch::Types::StopMetricStreamsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#namesArray<String>

The array of the names of metric streams to stop streaming.

This is an "all or nothing" operation. If you do not have permission to access all of the metric streams that you list here, then none of the streams that you list in the operation will stop streaming.

Returns:

  • (Array<String>)


5847
5848
5849
5850
5851
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5847

class StopMetricStreamsInput < Struct.new(
  :names)
  SENSITIVE = []
  include Aws::Structure
end