Class: Aws::CloudWatch::Types::StopMetricStreamsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatch::Types::StopMetricStreamsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#names ⇒ Array<String>
The array of the names of metric streams to stop streaming.
Instance Attribute Details
#names ⇒ Array<String>
The array of the names of metric streams to stop streaming.
This is an “all or nothing” operation. If you do not have permission to access all of the metric streams that you list here, then none of the streams that you list in the operation will stop streaming.
5411 5412 5413 5414 5415 |
# File 'lib/aws-sdk-cloudwatch/types.rb', line 5411 class StopMetricStreamsInput < Struct.new( :names) SENSITIVE = [] include Aws::Structure end |