Class: Aws::CloudWatch::Waiters::AlarmExists
- Inherits:
-
Object
- Object
- Aws::CloudWatch::Waiters::AlarmExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-cloudwatch/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AlarmExists
constructor
A new instance of AlarmExists.
-
#wait(params = {}) ⇒ Types::DescribeAlarmsOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AlarmExists
Returns a new instance of AlarmExists.
87 88 |
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 87
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
111 112 113 |
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 111 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeAlarmsOutput
Returns a response object which responds to the following methods:
- #composite_alarms => Array<Types::CompositeAlarm>
- #metric_alarms => Array<Types::MetricAlarm>
- #log_alarms => Array<Types::LogAlarm>
- #next_token => String
106 |
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 106
def wait: (
|