Class: Aws::CloudWatch::Waiters::AlarmMuteRuleExists
- Inherits:
-
Object
- Object
- Aws::CloudWatch::Waiters::AlarmMuteRuleExists
- Defined in:
- lib/aws-sdk-cloudwatch/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AlarmMuteRuleExists
constructor
A new instance of AlarmMuteRuleExists.
-
#wait(params = {}) ⇒ Types::GetAlarmMuteRuleOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AlarmMuteRuleExists
Returns a new instance of AlarmMuteRuleExists.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 122 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 5, poller: Aws::Waiters::Poller.new( operation_name: :get_alarm_mute_rule, acceptors: [ { "matcher" => "status", "expected" => 200, "state" => "success" }, { "matcher" => "status", "expected" => 404, "state" => "retry" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
152 153 154 |
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 152 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetAlarmMuteRuleOutput
Returns a response object which responds to the following methods:
-
#name => String
-
#alarm_mute_rule_arn => String
-
#description => String
-
#rule => Types::Rule
-
#mute_targets => Types::MuteTargets
-
#start_date => Time
-
#expire_date => Time
-
#status => String
-
#last_updated_timestamp => Time
-
#mute_type => String
147 148 149 |
# File 'lib/aws-sdk-cloudwatch/waiters.rb', line 147 def wait(params = {}) @waiter.wait(client: @client, params: params) end |